#[repr(u8)]pub enum ErrorReplyReason {
Execution(SimpleExecutionError),
UnavailableActor(SimpleUnavailableActorError),
RemovedFromWaitlist = 3,
Unsupported = 255,
}Expand description
Reason of error reply creation.
Variants
Execution(SimpleExecutionError)
Error reply was created due to underlying execution error.
Destination actor is unavailable, so it can’t process the message.
RemovedFromWaitlist = 3
Message has died in Waitlist as out of rent one.
Unsupported = 255
Unsupported reason of error reply. Variant exists for backward compatibility.
Implementations