pub struct ContextSettings {
pub sending_fee: u64,
pub scheduled_sending_fee: u64,
pub waiting_fee: u64,
pub waking_fee: u64,
pub reservation_fee: u64,
pub outgoing_limit: u32,
pub outgoing_bytes_limit: u32,
}Expand description
Context settings.
Fields
sending_fee: u64Fee for sending message.
scheduled_sending_fee: u64Fee for sending scheduled message.
waiting_fee: u64Fee for calling wait.
waking_fee: u64Fee for waking messages.
reservation_fee: u64Fee for creating reservation.
outgoing_limit: u32Limit of outgoing messages, that program can send in current message processing.
outgoing_bytes_limit: u32Limit of bytes in outgoing messages during current execution.
Implementations
Sourceimpl ContextSettings
impl ContextSettings
Sourcepub fn with_outgoing_limits(
outgoing_limit: u32,
outgoing_bytes_limit: u32,
) -> ContextSettings
pub fn with_outgoing_limits( outgoing_limit: u32, outgoing_bytes_limit: u32, ) -> ContextSettings
Returns default settings with specified outgoing messages limits.