pub struct MessageContext { /* private fields */ }Expand description
Context of currently processing incoming message.
Implementations
Sourceimpl MessageContext
impl MessageContext
Sourcepub fn new(
dispatch: IncomingDispatch,
program_id: ActorId,
settings: ContextSettings,
) -> MessageContext
pub fn new( dispatch: IncomingDispatch, program_id: ActorId, settings: ContextSettings, ) -> MessageContext
Create new message context.
Returns None if outgoing messages bytes limit exceeded.
Sourcepub fn settings(&self) -> &ContextSettings
pub fn settings(&self) -> &ContextSettings
Getter for inner settings.
Sourcepub fn kind(&self) -> DispatchKind
pub fn kind(&self) -> DispatchKind
Getter for inner dispatch kind
Sourcepub fn reply_sent(&self) -> bool
pub fn reply_sent(&self) -> bool
Return bool defining was reply sent within the execution.
Sourcepub fn init_program(
&mut self,
packet: InitPacket,
delay: u32,
) -> Result<(MessageId, ActorId), MessageError>
pub fn init_program( &mut self, packet: InitPacket, delay: u32, ) -> Result<(MessageId, ActorId), MessageError>
Send a new program initialization message.
Generates a new message from provided data packet. Returns message id and generated program id.
Sourcepub fn send_commit(
&mut self,
handle: u32,
packet: HandlePacket,
delay: u32,
reservation: Option<ReservationId>,
) -> Result<MessageId, MessageError>
pub fn send_commit( &mut self, handle: u32, packet: HandlePacket, delay: u32, reservation: Option<ReservationId>, ) -> Result<MessageId, MessageError>
Send a new program initialization message.
Generates message from provided data packet and stored by handle payload. Returns message id.
Sourcepub fn send_init(&mut self) -> Result<u32, MessageError>
pub fn send_init(&mut self) -> Result<u32, MessageError>
Provide space for storing payload for future message creation.
Returns it’s handle.
Sourcepub fn send_push(
&mut self,
handle: u32,
buffer: &[u8],
) -> Result<(), MessageError>
pub fn send_push( &mut self, handle: u32, buffer: &[u8], ) -> Result<(), MessageError>
Pushes payload into stored payload by handle.
Sourcepub fn send_push_input(
&mut self,
handle: u32,
range: CheckedRange,
) -> Result<(), MessageError>
pub fn send_push_input( &mut self, handle: u32, range: CheckedRange, ) -> Result<(), MessageError>
Pushes the incoming buffer/payload into stored payload by handle.
Sourcepub fn check_input_range(
&self,
offset: u32,
len: u32,
) -> Result<CheckedRange, MessageError>
pub fn check_input_range( &self, offset: u32, len: u32, ) -> Result<CheckedRange, MessageError>
Check if provided offset/len are correct for the current payload
limits. Result CheckedRange instance is accepted by
send_push_input/reply_push_input and has the method len
allowing to charge gas before the calls.
Sourcepub fn reply_commit(
&mut self,
packet: ReplyPacket,
reservation: Option<ReservationId>,
) -> Result<MessageId, ExtError>
pub fn reply_commit( &mut self, packet: ReplyPacket, reservation: Option<ReservationId>, ) -> Result<MessageId, ExtError>
Send reply message.
Generates reply from provided data packet and stored reply payload. Returns message id.
Sourcepub fn reply_push(&mut self, buffer: &[u8]) -> Result<(), ExtError>
pub fn reply_push(&mut self, buffer: &[u8]) -> Result<(), ExtError>
Pushes payload into stored reply payload.
Sourcepub fn reply_destination(&self) -> ActorId
pub fn reply_destination(&self) -> ActorId
Return reply destination.
Sourcepub fn reply_push_input(&mut self, range: CheckedRange) -> Result<(), ExtError>
pub fn reply_push_input(&mut self, range: CheckedRange) -> Result<(), ExtError>
Pushes the incoming message buffer into stored reply payload.
Sourcepub fn wake(
&mut self,
waker_id: MessageId,
delay: u32,
) -> Result<(), MessageError>
pub fn wake( &mut self, waker_id: MessageId, delay: u32, ) -> Result<(), MessageError>
Wake message by it’s message id.
Sourcepub fn reply_deposit(
&mut self,
message_id: MessageId,
amount: u64,
) -> Result<(), MessageError>
pub fn reply_deposit( &mut self, message_id: MessageId, amount: u64, ) -> Result<(), MessageError>
Create deposit to handle future reply on message id was sent.
Sourcepub fn current(&self) -> &IncomingMessage
pub fn current(&self) -> &IncomingMessage
Current processing incoming message.
Sourcepub fn program_id(&self) -> ActorId
pub fn program_id(&self) -> ActorId
Current program’s id.
Sourcepub fn drain(self) -> (ContextOutcome, ContextStore)
pub fn drain(self) -> (ContextOutcome, ContextStore)
Destructs context after execution and returns provided outcome and store.