MessageError

Enum MessageError 

#[non_exhaustive]
#[repr(u32)]
pub enum MessageError {
Show 15 variants MaxMessageSizeExceed = 300, OutgoingMessagesAmountLimitExceeded = 301, DuplicateReply = 302, DuplicateWaking = 303, LateAccess = 304, OutOfBounds = 305, DuplicateInit = 306, InsufficientValue = 307, InsufficientGasLimit = 308, DuplicateReplyDeposit = 309, IncorrectMessageForReplyDeposit = 310, OutgoingMessagesBytesLimitExceeded = 311, OutOfBoundsInputSliceOffset = 312, OutOfBoundsInputSliceLength = 313, InsufficientGasForDelayedSending = 399,
}
Error using messages.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MaxMessageSizeExceed = 300

Message has bigger then allowed one message size



OutgoingMessagesAmountLimitExceeded = 301

The error “Message limit exceeded” occurs when a program attempts to send more than the maximum amount of messages allowed within a single execution (current setting - 1024).



DuplicateReply = 302

The error occurs in case of attempt to send more than one replies.



DuplicateWaking = 303

The error occurs in attempt to get the same message from the waitlist again (which is waked already).



LateAccess = 304

An attempt to commit or push a payload into an already formed message.



OutOfBounds = 305

The error occurs in case of not valid identifier specified.



DuplicateInit = 306

The error occurs in attempt to initialize the same program twice within a single execution.



InsufficientValue = 307

Everything less than existential deposit but greater than 0 is not considered as available balance and not saved in DB. Value between 0 and existential deposit cannot be sent in message.



InsufficientGasLimit = 308

Everything less than mailbox threshold but greater than 0 is not considered as available gas limit and not inserted in mailbox.

Gas limit between 0 and mailbox threshold cannot be inserted in mailbox.



DuplicateReplyDeposit = 309

The error occurs when program tries to create reply deposit for message that already been created within the execution.



IncorrectMessageForReplyDeposit = 310

The error occurs when program tries to create reply deposit for message that wasn’t sent within the execution or for reply.



OutgoingMessagesBytesLimitExceeded = 311

The error occurs when program tries to send messages with total size bigger than allowed.



OutOfBoundsInputSliceOffset = 312

The error occurs when a wrong offset of the input buffer (currently executing message payload) is provided.



OutOfBoundsInputSliceLength = 313

The error occurs when a too big length value to form a slice (range) of the input buffer (currently executing message payload) is provided.



InsufficientGasForDelayedSending = 399

An error occurs in attempt to charge gas for dispatch stash hold.