#[derive(MaxEncodedLen)]
{
// Attributes available to this derive:
#[max_encoded_len_mod]
}
Available on crate feature
max-encoded-len only.Expand description
Derive parity_scale_codec::MaxEncodedLen for struct and enum.
Top level attribute
By default the macro will try to bound the types needed to implement MaxEncodedLen, but the
bounds can be specified manually with the top level attribute:
#[codec(mel_bound(T: MaxEncodedLen))]