pub trait PartialOrd<Rhs = Self>: PartialEq<Rhs>where
Rhs: ?Sized,{
// Required method
fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>;
// Provided methods
fn lt(&self, other: &Rhs) -> bool { ... }
fn le(&self, other: &Rhs) -> bool { ... }
fn gt(&self, other: &Rhs) -> bool { ... }
fn ge(&self, other: &Rhs) -> bool { ... }
}Expand description
Trait for types that form a partial order.
The lt, le, gt, and ge methods of this trait can be called using the <, <=, >, and
>= operators, respectively.
This trait should only contain the comparison logic for a type if one plans on only
implementing PartialOrd but not Ord. Otherwise the comparison logic should be in Ord
and this trait implemented with Some(self.cmp(other)).
The methods of this trait must be consistent with each other and with those of PartialEq.
The following conditions must hold:
a == bif and only ifpartial_cmp(a, b) == Some(Equal).a < bif and only ifpartial_cmp(a, b) == Some(Less)a > bif and only ifpartial_cmp(a, b) == Some(Greater)a <= bif and only ifa < b || a == ba >= bif and only ifa > b || a == ba != bif and only if!(a == b).
Conditions 2–5 above are ensured by the default implementation. Condition 6 is already ensured
by PartialEq.
If Ord is also implemented for Self and Rhs, it must also be consistent with
partial_cmp (see the documentation of that trait for the exact requirements). It’s easy to
accidentally make them disagree by deriving some of the traits and manually implementing others.
The comparison relations must satisfy the following conditions (for all a, b, c of type
A, B, C):
- Transitivity: if
A: PartialOrd<B>andB: PartialOrd<C>andA: PartialOrd<C>, thena < bandb < cimpliesa < c. The same must hold for both==and>. This must also work for longer chains, such as whenA: PartialOrd<B>,B: PartialOrd<C>,C: PartialOrd<D>, andA: PartialOrd<D>all exist. - Duality: if
A: PartialOrd<B>andB: PartialOrd<A>, thena < bif and only ifb > a.
Note that the B: PartialOrd<A> (dual) and A: PartialOrd<C> (transitive) impls are not forced
to exist, but these requirements apply whenever they do exist.
Violating these requirements is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Cross-crate considerations
Upholding the requirements stated above can become tricky when one crate implements PartialOrd
for a type of another crate (i.e., to allow comparing one of its own types with a type from the
standard library). The recommendation is to never implement this trait for a foreign type. In
other words, such a crate should do impl PartialOrd<ForeignType> for LocalType, but it should
not do impl PartialOrd<LocalType> for ForeignType.
This avoids the problem of transitive chains that criss-cross crate boundaries: for all local
types T, you may assume that no other crate will add impls that allow comparing T < U. In
other words, if other crates add impls that allow building longer transitive chains U1 < ... < T < V1 < ..., then all the types that appear to the right of T must be types that the crate
defining T already knows about. This rules out transitive chains where downstream crates can
add new impls that “stitch together” comparisons of foreign types in ways that violate
transitivity.
Not having such foreign impls also avoids forward compatibility issues where one crate adding
more PartialOrd implementations can cause build failures in downstream crates.
Corollaries
The following corollaries follow from the above requirements:
- irreflexivity of
<and>:!(a < a),!(a > a) - transitivity of
>: ifa > bandb > cthena > c - duality of
partial_cmp:partial_cmp(a, b) == partial_cmp(b, a).map(Ordering::reverse)
Strict and non-strict partial orders
The < and > operators behave according to a strict partial order. However, <= and >=
do not behave according to a non-strict partial order. That is because mathematically, a
non-strict partial order would require reflexivity, i.e. a <= a would need to be true for
every a. This isn’t always the case for types that implement PartialOrd, for example:
let a = f64::sqrt(-1.0);
assert_eq!(a <= a, false);Derivable
This trait can be used with #[derive].
When derived on structs, it will produce a
lexicographic ordering based on the
top-to-bottom declaration order of the struct’s members.
When derived on enums, variants are primarily ordered by their discriminants. Secondarily,
they are ordered by their fields. By default, the discriminant is smallest for variants at the
top, and largest for variants at the bottom. Here’s an example:
#[derive(PartialEq, PartialOrd)]
enum E {
Top,
Bottom,
}
assert!(E::Top < E::Bottom);However, manually setting the discriminants can override this default behavior:
#[derive(PartialEq, PartialOrd)]
enum E {
Top = 2,
Bottom = 1,
}
assert!(E::Bottom < E::Top);How can I implement PartialOrd?
PartialOrd only requires implementation of the partial_cmp method, with the others
generated from default implementations.
However it remains possible to implement the others separately for types which do not have a
total order. For example, for floating point numbers, NaN < 0 == false and NaN >= 0 == false
(cf. IEEE 754-2008 section 5.11).
PartialOrd requires your type to be PartialEq.
If your type is Ord, you can implement partial_cmp by using cmp:
use std::cmp::Ordering;
struct Person {
id: u32,
name: String,
height: u32,
}
impl PartialOrd for Person {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl Ord for Person {
fn cmp(&self, other: &Self) -> Ordering {
self.height.cmp(&other.height)
}
}
impl PartialEq for Person {
fn eq(&self, other: &Self) -> bool {
self.height == other.height
}
}
impl Eq for Person {}You may also find it useful to use partial_cmp on your type’s fields. Here is an example of
Person types who have a floating-point height field that is the only field to be used for
sorting:
use std::cmp::Ordering;
struct Person {
id: u32,
name: String,
height: f64,
}
impl PartialOrd for Person {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
self.height.partial_cmp(&other.height)
}
}
impl PartialEq for Person {
fn eq(&self, other: &Self) -> bool {
self.height == other.height
}
}Examples of incorrect PartialOrd implementations
use std::cmp::Ordering;
#[derive(PartialEq, Debug)]
struct Character {
health: u32,
experience: u32,
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.health.cmp(&other.health))
}
}
let a = Character {
health: 10,
experience: 5,
};
let b = Character {
health: 10,
experience: 77,
};
// Mistake: `PartialEq` and `PartialOrd` disagree with each other.
assert_eq!(a.partial_cmp(&b).unwrap(), Ordering::Equal); // a == b according to `PartialOrd`.
assert_ne!(a, b); // a != b according to `PartialEq`.Examples
let x: u32 = 0;
let y: u32 = 1;
assert_eq!(x < y, true);
assert_eq!(x.lt(&y), true);Required Methods
1.0.0 · Sourcefn partial_cmp(&self, other: &Rhs) -> Option<Ordering>
fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>
This method returns an ordering between self and other values if one exists.
Examples
use std::cmp::Ordering;
let result = 1.0.partial_cmp(&2.0);
assert_eq!(result, Some(Ordering::Less));
let result = 1.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Equal));
let result = 2.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Greater));When comparison is impossible:
let result = f64::NAN.partial_cmp(&1.0);
assert_eq!(result, None);Provided Methods
1.0.0 · Sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
Tests less than (for self and other) and is used by the < operator.
Examples
assert_eq!(1.0 < 1.0, false);
assert_eq!(1.0 < 2.0, true);
assert_eq!(2.0 < 1.0, false);1.0.0 · Sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
Tests less than or equal to (for self and other) and is used by the
<= operator.
Examples
assert_eq!(1.0 <= 1.0, true);
assert_eq!(1.0 <= 2.0, true);
assert_eq!(2.0 <= 1.0, false);Implementors
impl PartialOrd for DispatchStatus
impl PartialOrd for MessageWaitedType
impl PartialOrd for DispatchKind
impl PartialOrd for MultiSigner
impl PartialOrd for TypeDefPrimitive
impl PartialOrd for MetaForm
impl PartialOrd for PortableForm
impl PartialOrd for PolkadotConfig
impl PartialOrd for SubstrateConfig
impl PartialOrd for ErrorKind
impl PartialOrd for TransactionVersion
impl PartialOrd for MultiSignature
impl PartialOrd for ChildInfo
impl PartialOrd for CallContext
impl PartialOrd for Infallible
impl PartialOrd for Ordering
impl PartialOrd for AsciiChar
impl PartialOrd for IpAddr
impl PartialOrd for SocketAddr
impl PartialOrd for LineEnding
impl PartialOrd for BigEndian
impl PartialOrd for LittleEndian
impl PartialOrd for const_oid::error::Error
impl PartialOrd for ExtrinsicType
impl PartialOrd for HashType
impl PartialOrd for ParamType
impl PartialOrd for RegularParamType
impl PartialOrd for SyscallName
impl PartialOrd for ErrPtr
impl PartialOrd for Ptr
impl PartialOrd for gimli::common::SectionId
impl PartialOrd for ColumnType
impl PartialOrd for HexToArrayError
impl PartialOrd for HexToBytesError
impl PartialOrd for ExtensionType
impl PartialOrd for GeneralCategory
impl PartialOrd for log::Level
impl PartialOrd for log::LevelFilter
impl PartialOrd for Locale
impl PartialOrd for parity_bip39::language::Language
impl PartialOrd for Encoding
impl PartialOrd for regex_syntax::utf8::Utf8Sequence
impl PartialOrd for regex_syntax::utf8::Utf8Sequence
impl PartialOrd for Direction
impl PartialOrd for All
impl PartialOrd for SignOnly
impl PartialOrd for VerifyOnly
impl PartialOrd for ElligatorSwiftParty
impl PartialOrd for secp256k1::Error
impl PartialOrd for Parity
impl PartialOrd for OpCode
impl PartialOrd for Data
impl PartialOrd for TokenRegistry
impl PartialOrd for wasm_encoder::core::SectionId
impl PartialOrd for AbstractHeapType
impl PartialOrd for HeapType
impl PartialOrd for wasm_encoder::core::types::StorageType
impl PartialOrd for wasm_encoder::core::types::ValType
impl PartialOrd for CompositeInnerType
impl PartialOrd for wasmparser::readers::core::types::StorageType
impl PartialOrd for UnpackedIndex
impl PartialOrd for wasmparser::readers::core::types::ValType
impl PartialOrd for bool
impl PartialOrd for char
impl PartialOrd for f16
impl PartialOrd for f32
impl PartialOrd for f64
impl PartialOrd for f128
impl PartialOrd for i8
impl PartialOrd for i16
impl PartialOrd for i32
impl PartialOrd for i64
impl PartialOrd for i128
impl PartialOrd for isize
impl PartialOrd for !
impl PartialOrd for str
Implements comparison operations on strings.
Strings are compared lexicographically by their byte values. This compares Unicode code
points based on their positions in the code charts. This is not necessarily the same as
“alphabetical” order, which varies by language and locale. Comparing strings according to
culturally-accepted standards requires locale-specific data that is outside the scope of
the str type.
impl PartialOrd for u8
impl PartialOrd for u16
impl PartialOrd for u32
impl PartialOrd for u64
impl PartialOrd for u128
impl PartialOrd for ()
impl PartialOrd for usize
impl PartialOrd for WSAddress
impl PartialOrd for PanicBuffer
impl PartialOrd for ActorId
impl PartialOrd for CodeId
impl PartialOrd for MessageId
impl PartialOrd for ReservationId
impl PartialOrd for LimitedStrError
impl PartialOrd for IntoPageBufError
impl PartialOrd for PageBuf
impl PartialOrd for gclient::ext::gear_core::percent::Percent
impl PartialOrd for ReservationNonce
impl PartialOrd for gclient::ext::sp_runtime::app_crypto::ecdsa::AppPublic
impl PartialOrd for gclient::ext::sp_runtime::app_crypto::ed25519::AppPublic
impl PartialOrd for gclient::ext::sp_runtime::app_crypto::sr25519::AppPublic
impl PartialOrd for BigUint
impl PartialOrd for gclient::ext::sp_runtime::scale_info::prelude::time::Instant
impl PartialOrd for SystemTime
impl PartialOrd for MetaType
impl PartialOrd for gclient::ext::sp_runtime::AccountId32
impl PartialOrd for CryptoTypeId
impl PartialOrd for FixedI64
impl PartialOrd for FixedI128
impl PartialOrd for FixedU64
impl PartialOrd for FixedU128
impl PartialOrd for KeyTypeId
impl PartialOrd for PerU16
impl PartialOrd for Perbill
impl PartialOrd for gclient::ext::sp_runtime::Percent
impl PartialOrd for Permill
impl PartialOrd for Perquintill
impl PartialOrd for Rational128
impl PartialOrd for UintAuthorityId
impl PartialOrd for gclient::ext::subxt::backend::chain_head::rpc_methods::Bytes
impl PartialOrd for gclient::ext::subxt::config::polkadot::U256
impl PartialOrd for Url
URLs compare like their serialization.
impl PartialOrd for HeaderValue
impl PartialOrd for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::H128
impl PartialOrd for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::H384
impl PartialOrd for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::H768
impl PartialOrd for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::U128
impl PartialOrd for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::U512
impl PartialOrd for AccountId20
impl PartialOrd for gclient::ext::subxt::ext::subxt_rpcs::methods::chain_head::Bytes
impl PartialOrd for gclient::ext::subxt::utils::AccountId32
impl PartialOrd for Encoded
impl PartialOrd for gclient::ext::subxt::utils::H160
impl PartialOrd for gclient::ext::subxt::utils::H256
impl PartialOrd for gclient::ext::subxt::utils::H512
impl PartialOrd for ByteStr
impl PartialOrd for ByteString
impl PartialOrd for CString
impl PartialOrd for String
impl PartialOrd for Capabilities
impl PartialOrd for gclient::ext::sp_core::offchain::Duration
impl PartialOrd for HttpRequestId
impl PartialOrd for Timestamp
impl PartialOrd for ChildTrieParentKeyId
impl PartialOrd for PrefixedStorageKey
impl PartialOrd for StorageData
impl PartialOrd for StorageKey
impl PartialOrd for TrackedStorageKey
impl PartialOrd for gclient::ext::sp_core::Bytes
impl PartialOrd for gclient::ext::sp_core::H160
impl PartialOrd for gclient::ext::sp_core::H256
impl PartialOrd for gclient::ext::sp_core::H512
impl PartialOrd for OpaquePeerId
impl PartialOrd for gclient::ext::sp_core::U256
impl PartialOrd for gclient::ext::sp_core::U512
impl PartialOrd for TypeId
impl PartialOrd for PhantomPinned
impl PartialOrd for gclient::ext::sp_core::sp_std::time::Duration
impl PartialOrd for CpuidResult
impl PartialOrd for CStr
impl PartialOrd for core::fmt::Error
impl PartialOrd for Ipv4Addr
impl PartialOrd for Ipv6Addr
impl PartialOrd for SocketAddrV4
impl PartialOrd for SocketAddrV6
impl PartialOrd for Location<'_>
impl PartialOrd for Alignment
impl PartialOrd for OsStr
impl PartialOrd for OsString
impl PartialOrd for std::path::Path
impl PartialOrd for PathBuf
impl PartialOrd for aho_corasick::util::primitives::PatternID
impl PartialOrd for aho_corasick::util::primitives::StateID
impl PartialOrd for bitcoin_hashes::hash160::Hash
impl PartialOrd for bitcoin_hashes::ripemd160::Hash
impl PartialOrd for bitcoin_hashes::sha1::Hash
impl PartialOrd for bitcoin_hashes::sha256::Hash
impl PartialOrd for Midstate
impl PartialOrd for bitcoin_hashes::sha256d::Hash
impl PartialOrd for bitcoin_hashes::sha512::Hash
impl PartialOrd for bitcoin_hashes::sha512_256::Hash
impl PartialOrd for bitcoin_hashes::siphash24::Hash
impl PartialOrd for Lsb0
impl PartialOrd for Msb0
impl PartialOrd for bytes::bytes::Bytes
impl PartialOrd for BytesMut
impl PartialOrd for ObjectIdentifier
impl PartialOrd for VerificationKeyBytes
impl PartialOrd for Register
impl PartialOrd for DwAccess
impl PartialOrd for DwAddr
impl PartialOrd for DwAt
impl PartialOrd for DwAte
impl PartialOrd for DwCc
impl PartialOrd for DwCfa
impl PartialOrd for DwChildren
impl PartialOrd for DwDefaulted
impl PartialOrd for DwDs
impl PartialOrd for DwDsc
impl PartialOrd for DwEhPe
impl PartialOrd for DwEnd
impl PartialOrd for DwForm
impl PartialOrd for DwId
impl PartialOrd for DwIdx
impl PartialOrd for DwInl
impl PartialOrd for DwLang
impl PartialOrd for DwLle
impl PartialOrd for DwLnct
impl PartialOrd for DwLne
impl PartialOrd for DwLns
impl PartialOrd for DwMacro
impl PartialOrd for DwOp
impl PartialOrd for DwOrd
impl PartialOrd for DwRle
impl PartialOrd for DwSect
impl PartialOrd for DwSectV2
impl PartialOrd for DwTag
impl PartialOrd for DwUt
impl PartialOrd for DwVirtuality
impl PartialOrd for DwVis
impl PartialOrd for ArangeEntry
impl PartialOrd for NonZeroU256
impl PartialOrd for gsys::Percent
impl PartialOrd for StatusCode
impl PartialOrd for Authority
Case-insensitive ordering
Examples
let authority: Authority = "DEF.com".parse().unwrap();
assert!(authority < "ghi.com");
assert!(authority > "abc.com");impl PartialOrd for PathAndQuery
impl PartialOrd for Version
impl PartialOrd for ReasonPhrase
impl PartialOrd for Other
impl PartialOrd for icu_locale_core::extensions::private::other::Subtag
impl PartialOrd for Private
impl PartialOrd for Fields
impl PartialOrd for icu_locale_core::extensions::transform::key::Key
impl PartialOrd for icu_locale_core::extensions::transform::value::Value
impl PartialOrd for Attribute
impl PartialOrd for Attributes
impl PartialOrd for icu_locale_core::extensions::unicode::key::Key
impl PartialOrd for Keywords
impl PartialOrd for SubdivisionId
impl PartialOrd for SubdivisionSuffix
impl PartialOrd for icu_locale_core::extensions::unicode::value::Value
impl PartialOrd for icu_locale_core::subtags::language::Language
impl PartialOrd for Region
impl PartialOrd for icu_locale_core::subtags::script::Script
impl PartialOrd for icu_locale_core::subtags::Subtag
impl PartialOrd for icu_locale_core::subtags::variant::Variant
impl PartialOrd for Variants
impl PartialOrd for GeneralCategoryULE
impl PartialOrd for BidiClass
impl PartialOrd for CanonicalCombiningClass
impl PartialOrd for EastAsianWidth
impl PartialOrd for GeneralCategoryOutOfBoundsError
impl PartialOrd for GraphemeClusterBreak
impl PartialOrd for HangulSyllableType
impl PartialOrd for IndicSyllabicCategory
impl PartialOrd for JoiningType
impl PartialOrd for LineBreak
impl PartialOrd for icu_properties::props::Script
impl PartialOrd for SentenceBreak
impl PartialOrd for VerticalOrientation
impl PartialOrd for WordBreak
impl PartialOrd for DataMarkerId
impl PartialOrd for DataMarkerIdHash
impl PartialOrd for DataMarkerInfo
impl PartialOrd for DataMarkerAttributes
impl PartialOrd for DataRequestMetadata
impl PartialOrd for libsecp256k1_core::field::Field
impl PartialOrd for Interest
impl PartialOrd for mio::token::Token
impl PartialOrd for Mnemonic
impl PartialOrd for PotentialCodePoint
impl PartialOrd for PotentialUtf8
impl PartialOrd for PotentialUtf16
impl PartialOrd for primitive_types::H128
impl PartialOrd for primitive_types::H384
impl PartialOrd for primitive_types::H768
impl PartialOrd for primitive_types::U128
impl PartialOrd for LazyStateID
impl PartialOrd for Unit
impl PartialOrd for NonMaxUsize
impl PartialOrd for regex_automata::util::primitives::PatternID
impl PartialOrd for SmallIndex
impl PartialOrd for regex_automata::util::primitives::StateID
impl PartialOrd for regex_syntax::ast::Position
impl PartialOrd for regex_syntax::ast::Position
impl PartialOrd for regex_syntax::ast::Span
impl PartialOrd for regex_syntax::ast::Span
impl PartialOrd for regex_syntax::hir::literal::Literal
impl PartialOrd for regex_syntax::hir::literal::Literal
impl PartialOrd for regex_syntax::hir::ClassBytesRange
impl PartialOrd for regex_syntax::hir::ClassBytesRange
impl PartialOrd for regex_syntax::hir::ClassUnicodeRange
impl PartialOrd for regex_syntax::hir::ClassUnicodeRange
impl PartialOrd for regex_syntax::utf8::Utf8Range
impl PartialOrd for regex_syntax::utf8::Utf8Range
impl PartialOrd for Opcode
impl PartialOrd for UnixTime
impl PartialOrd for schnorrkel::keys::PublicKey
impl PartialOrd for RistrettoBoth
impl PartialOrd for VRFInOut
impl PartialOrd for VRFPreOut
impl PartialOrd for secp256k1_sys::recovery::RecoverableSignature
secp256k1_fuzz only.impl PartialOrd for secp256k1_sys::ElligatorSwift
impl PartialOrd for secp256k1_sys::Keypair
secp256k1_fuzz only.impl PartialOrd for secp256k1_sys::PublicKey
secp256k1_fuzz only.impl PartialOrd for secp256k1_sys::Signature
secp256k1_fuzz only.impl PartialOrd for secp256k1_sys::XOnlyPublicKey
secp256k1_fuzz only.impl PartialOrd for secp256k1::ecdsa::recovery::RecoverableSignature
impl PartialOrd for RecoveryId
impl PartialOrd for SerializedSignature
impl PartialOrd for secp256k1::ecdsa::Signature
impl PartialOrd for secp256k1::ellswift::ElligatorSwift
impl PartialOrd for InvalidParityValue
impl PartialOrd for secp256k1::key::Keypair
impl PartialOrd for secp256k1::key::PublicKey
impl PartialOrd for secp256k1::key::XOnlyPublicKey
impl PartialOrd for Scalar
impl PartialOrd for secp256k1::schnorr::Signature
impl PartialOrd for Message
impl PartialOrd for CloseReason
impl PartialOrd for RationalInfinite
impl PartialOrd for ss58_registry::token::Token
impl PartialOrd for TokenAmount
impl PartialOrd for Date
impl PartialOrd for time::duration::Duration
impl PartialOrd for time::instant::Instant
impl PartialOrd for OffsetDateTime
impl PartialOrd for PrimitiveDateTime
impl PartialOrd for Time
impl PartialOrd for UtcOffset
impl PartialOrd for AnyDelimiterCodec
impl PartialOrd for BytesCodec
impl PartialOrd for LinesCodec
impl PartialOrd for Ready
impl PartialOrd for tokio::runtime::task::id::Id
impl PartialOrd for tokio::time::instant::Instant
impl PartialOrd for tracing_core::metadata::Level
impl PartialOrd for tracing_core::metadata::LevelFilter
impl PartialOrd for Directive
impl PartialOrd for FmtSpan
impl PartialOrd for trie_db::Bytes
impl PartialOrd for ATerm
impl PartialOrd for B0
impl PartialOrd for B1
impl PartialOrd for Z0
impl PartialOrd for Equal
impl PartialOrd for Greater
impl PartialOrd for Less
impl PartialOrd for UTerm
impl PartialOrd for wasm_encoder::core::types::FieldType
impl PartialOrd for wasm_encoder::core::types::RefType
impl PartialOrd for SymbolFlags
impl PartialOrd for ArrayType
impl PartialOrd for CompositeType
impl PartialOrd for ContType
impl PartialOrd for wasmparser::readers::core::types::FieldType
impl PartialOrd for FuncType
impl PartialOrd for PackedIndex
impl PartialOrd for RecGroup
impl PartialOrd for wasmparser::readers::core::types::RefType
impl PartialOrd for StructType
impl PartialOrd for SubType
impl PartialOrd for ValidatorId
impl PartialOrd for CoreTypeId
impl PartialOrd for RecGroupId
impl PartialOrd for Const
impl PartialOrd for Mut
impl PartialOrd for NullPtrError
impl PartialOrd for SliceTokensLocation
impl PartialOrd for StrTokensLocation
impl PartialOrd for CharULE
impl PartialOrd for Index8
impl PartialOrd for Index16
impl PartialOrd for Index32
impl PartialOrd<IpAddr> for Ipv4Addr
impl PartialOrd<IpAddr> for Ipv6Addr
impl PartialOrd<Level> for log::LevelFilter
impl PartialOrd<LevelFilter> for log::Level
impl PartialOrd<char> for PotentialCodePoint
impl PartialOrd<str> for HeaderValue
impl PartialOrd<str> for OsStr
impl PartialOrd<str> for OsString
impl PartialOrd<str> for bytes::bytes::Bytes
impl PartialOrd<str> for BytesMut
impl PartialOrd<str> for Authority
impl PartialOrd<str> for PathAndQuery
impl PartialOrd<str> for PotentialUtf8
impl PartialOrd<Instant> for time::instant::Instant
impl PartialOrd<SystemTime> for OffsetDateTime
std only.impl PartialOrd<Vec<u8>> for bytes::bytes::Bytes
impl PartialOrd<Vec<u8>> for BytesMut
impl PartialOrd<HeaderValue> for str
impl PartialOrd<HeaderValue> for String
impl PartialOrd<HeaderValue> for [u8]
impl PartialOrd<String> for HeaderValue
impl PartialOrd<String> for bytes::bytes::Bytes
impl PartialOrd<String> for BytesMut
impl PartialOrd<String> for Authority
impl PartialOrd<String> for PathAndQuery
impl PartialOrd<Duration> for time::duration::Duration
impl PartialOrd<Ipv4Addr> for IpAddr
impl PartialOrd<Ipv6Addr> for IpAddr
impl PartialOrd<OsStr> for std::path::Path
impl PartialOrd<OsStr> for PathBuf
impl PartialOrd<OsString> for std::path::Path
impl PartialOrd<OsString> for PathBuf
impl PartialOrd<Path> for OsStr
impl PartialOrd<Path> for OsString
impl PartialOrd<Path> for PathBuf
impl PartialOrd<PathBuf> for OsStr
impl PartialOrd<PathBuf> for OsString
impl PartialOrd<PathBuf> for std::path::Path
impl PartialOrd<Bytes> for &str
impl PartialOrd<Bytes> for &[u8]
impl PartialOrd<Bytes> for str
impl PartialOrd<Bytes> for gclient::ext::sp_runtime::Vec<u8>
impl PartialOrd<Bytes> for String
impl PartialOrd<Bytes> for [u8]
impl PartialOrd<BytesMut> for &str
impl PartialOrd<BytesMut> for &[u8]
impl PartialOrd<BytesMut> for str
impl PartialOrd<BytesMut> for gclient::ext::sp_runtime::Vec<u8>
impl PartialOrd<BytesMut> for String
impl PartialOrd<BytesMut> for [u8]
impl PartialOrd<Authority> for str
impl PartialOrd<Authority> for String
impl PartialOrd<PathAndQuery> for str
impl PartialOrd<PathAndQuery> for String
impl PartialOrd<PotentialCodePoint> for char
impl PartialOrd<PotentialUtf8> for str
impl PartialOrd<SerializedSignature> for [u8]
impl PartialOrd<Duration> for gclient::ext::sp_core::sp_std::time::Duration
impl PartialOrd<Instant> for gclient::ext::sp_runtime::scale_info::prelude::time::Instant
impl PartialOrd<OffsetDateTime> for SystemTime
std only.impl PartialOrd<Level> for tracing_core::metadata::LevelFilter
impl PartialOrd<LevelFilter> for tracing_core::metadata::Level
impl PartialOrd<[u8]> for HeaderValue
impl PartialOrd<[u8]> for bytes::bytes::Bytes
impl PartialOrd<[u8]> for BytesMut
impl PartialOrd<[u8]> for SerializedSignature
impl<'a> PartialOrd for OpaqueDigestItemId<'a>
impl<'a> PartialOrd for gclient::ext::subxt::ext::jsonrpsee::http_client::types::Id<'a>
impl<'a> PartialOrd for Component<'a>
impl<'a> PartialOrd for Prefix<'a>
impl<'a> PartialOrd for Incoming<'a>
impl<'a> PartialOrd for PhantomContravariantLifetime<'a>
impl<'a> PartialOrd for PhantomCovariantLifetime<'a>
impl<'a> PartialOrd for PhantomInvariantLifetime<'a>
impl<'a> PartialOrd for Components<'a>
impl<'a> PartialOrd for PrefixComponent<'a>
impl<'a> PartialOrd for Metadata<'a>
impl<'a> PartialOrd for MetadataBuilder<'a>
impl<'a> PartialOrd for DecimalStr<'a>
impl<'a> PartialOrd for InfinityStr<'a>
impl<'a> PartialOrd for MinusSignStr<'a>
impl<'a> PartialOrd for NanStr<'a>
impl<'a> PartialOrd for PlusSignStr<'a>
impl<'a> PartialOrd for SeparatorStr<'a>
impl<'a> PartialOrd for Ident<'a>
impl<'a> PartialOrd for password_hash::value::Value<'a>
impl<'a> PartialOrd for NibbleSlice<'a>
impl<'a> PartialOrd<&'a str> for Authority
impl<'a> PartialOrd<&'a str> for PathAndQuery
impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, str>
impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, ByteStr>
impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, [u8]>
impl<'a> PartialOrd<&'a OsStr> for std::path::Path
impl<'a> PartialOrd<&'a OsStr> for PathBuf
impl<'a> PartialOrd<&'a Path> for OsStr
impl<'a> PartialOrd<&'a Path> for OsString
impl<'a> PartialOrd<&'a Path> for PathBuf
impl<'a> PartialOrd<&ByteStr> for ByteString
impl<'a> PartialOrd<Cow<'_, str>> for ByteString
impl<'a> PartialOrd<Cow<'_, ByteStr>> for ByteString
impl<'a> PartialOrd<Cow<'_, [u8]>> for ByteString
impl<'a> PartialOrd<Cow<'a, str>> for &'a ByteStr
impl<'a> PartialOrd<Cow<'a, ByteStr>> for &'a ByteStr
impl<'a> PartialOrd<Cow<'a, OsStr>> for std::path::Path
impl<'a> PartialOrd<Cow<'a, OsStr>> for PathBuf
impl<'a> PartialOrd<Cow<'a, Path>> for OsStr
impl<'a> PartialOrd<Cow<'a, Path>> for OsString
impl<'a> PartialOrd<Cow<'a, Path>> for std::path::Path
impl<'a> PartialOrd<Cow<'a, Path>> for PathBuf
impl<'a> PartialOrd<Cow<'a, [u8]>> for &'a ByteStr
impl<'a> PartialOrd<HeaderValue> for &'a str
impl<'a> PartialOrd<HeaderValue> for &'a HeaderValue
impl<'a> PartialOrd<ByteStr> for ByteString
impl<'a> PartialOrd<ByteString> for &ByteStr
impl<'a> PartialOrd<ByteString> for Cow<'_, str>
impl<'a> PartialOrd<ByteString> for Cow<'_, ByteStr>
impl<'a> PartialOrd<ByteString> for Cow<'_, [u8]>
impl<'a> PartialOrd<ByteString> for ByteStr
impl<'a> PartialOrd<OsStr> for &'a std::path::Path
impl<'a> PartialOrd<OsStr> for Cow<'a, Path>
impl<'a> PartialOrd<OsString> for &'a std::path::Path
impl<'a> PartialOrd<OsString> for Cow<'a, Path>
impl<'a> PartialOrd<Path> for &'a OsStr
impl<'a> PartialOrd<Path> for Cow<'a, OsStr>
impl<'a> PartialOrd<Path> for Cow<'a, Path>
impl<'a> PartialOrd<PathBuf> for &'a OsStr
impl<'a> PartialOrd<PathBuf> for &'a std::path::Path
impl<'a> PartialOrd<PathBuf> for Cow<'a, OsStr>
impl<'a> PartialOrd<PathBuf> for Cow<'a, Path>
impl<'a> PartialOrd<Authority> for &'a str
impl<'a> PartialOrd<PathAndQuery> for &'a str
impl<'a, 'b> PartialOrd<&'a OsStr> for OsString
impl<'a, 'b> PartialOrd<&'a Path> for Cow<'b, OsStr>
impl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<&'b Path> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for &'b OsStr
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for OsStr
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for OsString
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b OsStr
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b std::path::Path
impl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a std::path::Path
impl<'a, 'b> PartialOrd<OsStr> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<OsStr> for OsString
impl<'a, 'b> PartialOrd<OsString> for &'a OsStr
impl<'a, 'b> PartialOrd<OsString> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<OsString> for OsStr
impl<'a, B> PartialOrd for Cow<'a, B>
impl<'a, O1, O2, T1, T2> PartialOrd<BitBox<T2, O2>> for &'a BitSlice<T1, O1>
tarpaulin_include only.impl<'a, O1, O2, T1, T2> PartialOrd<BitBox<T2, O2>> for &'a mut BitSlice<T1, O1>
tarpaulin_include only.impl<'a, T1, T2, O1, O2> PartialOrd<BitVec<T2, O2>> for &'a BitSlice<T1, O1>
tarpaulin_include only.impl<'a, T1, T2, O1, O2> PartialOrd<BitVec<T2, O2>> for &'a mut BitSlice<T1, O1>
tarpaulin_include only.impl<'a, T> PartialOrd for Symbol<'a, T>where
T: PartialOrd + 'a,
impl<'a, T> PartialOrd for ZeroVec<'a, T>where
T: AsULE + PartialOrd,
impl<'a, T> PartialOrd<&'a T> for HeaderValue
impl<'a, T> PartialOrd<&'a T> for bytes::bytes::Bytes
impl<'a, T> PartialOrd<&'a T> for BytesMut
impl<'a, T, BoundSelf, BoundRhs> PartialOrd<BoundedSlice<'a, T, BoundRhs>> for BoundedSlice<'a, T, BoundSelf>
impl<'a, T, BoundSelf, BoundRhs> PartialOrd<BoundedSlice<'a, T, BoundRhs>> for BoundedVec<T, BoundSelf>
impl<'a, T, BoundSelf, BoundRhs> PartialOrd<BoundedSlice<'a, T, BoundRhs>> for WeakBoundedVec<T, BoundSelf>
impl<'a, T, BoundSelf, BoundRhs> PartialOrd<BoundedVec<T, BoundRhs>> for BoundedSlice<'a, T, BoundSelf>
impl<'a, T, BoundSelf, BoundRhs> PartialOrd<WeakBoundedVec<T, BoundRhs>> for BoundedSlice<'a, T, BoundSelf>
impl<'a, T, F> PartialOrd for VarZeroVec<'a, T, F>
impl<'a, T, O> PartialOrd for IterOnes<'a, T, O>
impl<'a, T, O> PartialOrd for IterZeros<'a, T, O>
impl<'a, V> PartialOrd for VarZeroCow<'a, V>
impl<'a, const N: usize> PartialOrd for LimitedStr<'a, N>
impl<'buf> PartialOrd for AllPreallocated<'buf>
impl<'buf> PartialOrd for SignOnlyPreallocated<'buf>
impl<'buf> PartialOrd for VerifyOnlyPreallocated<'buf>
impl<'s, T> PartialOrd for SliceVec<'s, T>where
T: PartialOrd,
impl<A> PartialOrd for TinyVec<A>
impl<A> PartialOrd for SmallVec<A>
impl<A> PartialOrd for tinyvec::arrayvec::ArrayVec<A>
impl<A, B> PartialOrd for Tuple2ULE<A, B>
impl<A, B> PartialOrd for VarTuple<A, B>where
A: PartialOrd,
B: PartialOrd,
impl<A, B> PartialOrd<&B> for &A
impl<A, B> PartialOrd<&mut B> for &mut A
impl<A, B, C> PartialOrd for Tuple3ULE<A, B, C>
impl<A, B, C, D> PartialOrd for Tuple4ULE<A, B, C, D>
impl<A, B, C, D, E> PartialOrd for Tuple5ULE<A, B, C, D, E>where
A: PartialOrd + ULE,
B: PartialOrd + ULE,
C: PartialOrd + ULE,
D: PartialOrd + ULE,
E: PartialOrd + ULE,
impl<A, B, C, D, E, F> PartialOrd for Tuple6ULE<A, B, C, D, E, F>where
A: PartialOrd + ULE,
B: PartialOrd + ULE,
C: PartialOrd + ULE,
D: PartialOrd + ULE,
E: PartialOrd + ULE,
F: PartialOrd + ULE,
impl<A, B, C, D, E, F, Format> PartialOrd for Tuple6VarULE<A, B, C, D, E, F, Format>where
A: PartialOrd + VarULE + ?Sized,
B: PartialOrd + VarULE + ?Sized,
C: PartialOrd + VarULE + ?Sized,
D: PartialOrd + VarULE + ?Sized,
E: PartialOrd + VarULE + ?Sized,
F: PartialOrd + VarULE + ?Sized,
Format: VarZeroVecFormat,
impl<A, B, C, D, E, Format> PartialOrd for Tuple5VarULE<A, B, C, D, E, Format>where
A: PartialOrd + VarULE + ?Sized,
B: PartialOrd + VarULE + ?Sized,
C: PartialOrd + VarULE + ?Sized,
D: PartialOrd + VarULE + ?Sized,
E: PartialOrd + VarULE + ?Sized,
Format: VarZeroVecFormat,
impl<A, B, C, D, Format> PartialOrd for Tuple4VarULE<A, B, C, D, Format>where
A: PartialOrd + VarULE + ?Sized,
B: PartialOrd + VarULE + ?Sized,
C: PartialOrd + VarULE + ?Sized,
D: PartialOrd + VarULE + ?Sized,
Format: VarZeroVecFormat,
impl<A, B, C, Format> PartialOrd for Tuple3VarULE<A, B, C, Format>where
A: PartialOrd + VarULE + ?Sized,
B: PartialOrd + VarULE + ?Sized,
C: PartialOrd + VarULE + ?Sized,
Format: VarZeroVecFormat,
impl<A, B, Format> PartialOrd for Tuple2VarULE<A, B, Format>
impl<A, O, Rhs> PartialOrd<Rhs> for BitArray<A, O>where
A: BitViewSized,
O: BitOrder,
BitSlice<<A as BitView>::Store, O>: PartialOrd<Rhs>,
Rhs: ?Sized,
tarpaulin_include only.impl<A, T, O> PartialOrd<BitArray<A, O>> for BitSlice<T, O>
tarpaulin_include only.impl<A, V> PartialOrd for VarTupleULE<A, V>
impl<AccountId, AccountIndex> PartialOrd for MultiAddress<AccountId, AccountIndex>where
AccountId: PartialOrd,
AccountIndex: PartialOrd,
impl<ArgsData, ReturnTy> PartialOrd for gclient::ext::subxt::runtime_api::DefaultPayload<ArgsData, ReturnTy>where
ArgsData: PartialOrd,
impl<ArgsData, ReturnTy> PartialOrd for gclient::ext::subxt::view_functions::DefaultPayload<ArgsData, ReturnTy>where
ArgsData: PartialOrd,
impl<CallData> PartialOrd for gclient::ext::subxt::tx::DefaultPayload<CallData>where
CallData: PartialOrd,
impl<Dyn> PartialOrd for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<E> PartialOrd for I16Bytes<E>where
E: PartialOrd + Endian,
impl<E> PartialOrd for I32Bytes<E>where
E: PartialOrd + Endian,
impl<E> PartialOrd for I64Bytes<E>where
E: PartialOrd + Endian,
impl<E> PartialOrd for U16Bytes<E>where
E: PartialOrd + Endian,
impl<E> PartialOrd for U32Bytes<E>where
E: PartialOrd + Endian,
impl<E> PartialOrd for U64Bytes<E>where
E: PartialOrd + Endian,
impl<F> PartialOrd for Fwhere
F: FnPtr,
impl<H> PartialOrd for BlockRef<H>where
H: PartialOrd,
impl<Inner> PartialOrd for Frozen<Inner>where
Inner: PartialOrd + Mutability,
impl<K> PartialOrd for StaticStorageKey<K>where
K: PartialOrd,
impl<K, V> PartialOrd for indexmap::map::slice::Slice<K, V>where
K: PartialOrd,
V: PartialOrd,
impl<K, V, A> PartialOrd for BTreeMap<K, V, A>
impl<K, V, S> PartialOrd for BoundedBTreeMap<K, V, S>
impl<K, V, S> PartialOrd for LiteMap<K, V, S>
impl<Keys, ReturnTy, Fetchable, Defaultable, Iterable> PartialOrd for gclient::ext::subxt::storage::DefaultAddress<Keys, ReturnTy, Fetchable, Defaultable, Iterable>where
Keys: StorageKey + PartialOrd,
impl<L, R> PartialOrd for Either<L, R>where
L: PartialOrd,
R: PartialOrd,
impl<M1, M2, O1, O2, T1, T2> PartialOrd<BitRef<'_, M2, T2, O2>> for BitRef<'_, M1, T1, O1>
tarpaulin_include only.impl<M1, M2, T1, T2> PartialOrd<Address<M2, T2>> for Address<M1, T1>where
M1: Mutability,
M2: Mutability,
impl<M1, M2, T1, T2, O> PartialOrd<BitPtr<M2, T2, O>> for BitPtr<M1, T1, O>
impl<M, T, O> PartialOrd<&bool> for BitRef<'_, M, T, O>
tarpaulin_include only.impl<M, T, O> PartialOrd<bool> for BitRef<'_, M, T, O>
tarpaulin_include only.impl<O1, O2, T1, T2> PartialOrd<BitBox<T2, O2>> for BitSlice<T1, O1>
tarpaulin_include only.impl<Ptr, Q> PartialOrd<Pin<Q>> for Pin<Ptr>
impl<R> PartialOrd for BitEnd<R>where
R: PartialOrd + BitRegister,
impl<R> PartialOrd for BitIdx<R>where
R: PartialOrd + BitRegister,
impl<R> PartialOrd for BitIdxError<R>where
R: PartialOrd + BitRegister,
impl<R> PartialOrd for BitMask<R>where
R: PartialOrd + BitRegister,
impl<R> PartialOrd for BitPos<R>where
R: PartialOrd + BitRegister,
impl<R> PartialOrd for BitSel<R>where
R: PartialOrd + BitRegister,
impl<RFM, SD, SUM> PartialOrd for ScheduledTask<RFM, SD, SUM>
impl<ReturnTy> PartialOrd for gclient::ext::subxt::constants::DefaultAddress<ReturnTy>
impl<ReturnTy, IsDecodable> PartialOrd for StaticAddress<ReturnTy, IsDecodable>
impl<S> PartialOrd for Host<S>where
S: PartialOrd,
impl<Storage> PartialOrd for __BindgenBitfieldUnit<Storage>where
Storage: PartialOrd,
impl<T1, T2, O1, O2> PartialOrd<&BitSlice<T2, O2>> for &mut BitSlice<T1, O1>
impl<T1, T2, O1, O2> PartialOrd<&BitSlice<T2, O2>> for BitSlice<T1, O1>
impl<T1, T2, O1, O2> PartialOrd<&mut BitSlice<T2, O2>> for &BitSlice<T1, O1>
impl<T1, T2, O1, O2> PartialOrd<&mut BitSlice<T2, O2>> for BitSlice<T1, O1>
impl<T1, T2, O1, O2> PartialOrd<BitSlice<T2, O2>> for &BitSlice<T1, O1>
impl<T1, T2, O1, O2> PartialOrd<BitSlice<T2, O2>> for &mut BitSlice<T1, O1>
impl<T1, T2, O1, O2> PartialOrd<BitSlice<T2, O2>> for BitSlice<T1, O1>
Compares two BitSlices by semantic — not representational — ordering.
The comparison sorts by testing at each index if one slice has a high bit where the other has a low. At the first index where the slices differ, the slice with the high bit is greater. If the slices are equal until at least one terminates, then they are compared by length.
impl<T1, T2, O1, O2> PartialOrd<BitVec<T2, O2>> for BitSlice<T1, O1>
tarpaulin_include only.impl<T> PartialOrd for TypeDef<T>where
T: PartialOrd + Form,
impl<T> PartialOrd for Poll<T>where
T: PartialOrd,
impl<T> PartialOrd for Option<T>where
T: PartialOrd,
impl<T> PartialOrd for BitPtrError<T>where
T: PartialOrd + BitStore,
impl<T> PartialOrd for BitSpanError<T>where
T: PartialOrd + BitStore,
impl<T> PartialOrd for UnitSectionOffset<T>where
T: PartialOrd,
impl<T> PartialOrd for *const Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.
impl<T> PartialOrd for *mut Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the <*mut T>::addr method.
impl<T> PartialOrd for [T]where
T: PartialOrd,
Implements comparison of slices lexicographically.
impl<T> PartialOrd for (T₁, T₂, …, Tₙ)where
T: PartialOrd,
This trait is implemented for tuples up to twelve items long.
impl<T> PartialOrd for OptionBound<T>where
T: PartialOrd,
impl<T> PartialOrd for Compact<T>where
T: PartialOrd,
impl<T> PartialOrd for UntrackedSymbol<T>where
T: PartialOrd,
impl<T> PartialOrd for gclient::ext::sp_runtime::scale_info::Field<T>
impl<T> PartialOrd for gclient::ext::sp_runtime::scale_info::Path<T>
impl<T> PartialOrd for Type<T>
impl<T> PartialOrd for TypeDefArray<T>
impl<T> PartialOrd for TypeDefBitSequence<T>
impl<T> PartialOrd for TypeDefCompact<T>
impl<T> PartialOrd for TypeDefComposite<T>where
T: PartialOrd + Form,
impl<T> PartialOrd for TypeDefSequence<T>
impl<T> PartialOrd for TypeDefTuple<T>
impl<T> PartialOrd for TypeDefVariant<T>where
T: PartialOrd + Form,
impl<T> PartialOrd for TypeParameter<T>
impl<T> PartialOrd for gclient::ext::sp_runtime::scale_info::Variant<T>
impl<T> PartialOrd for PhantomData<T>where
T: ?Sized,
impl<T> PartialOrd for AllowStdIo<T>where
T: PartialOrd,
impl<T> PartialOrd for StorageKeyValuePair<T>where
T: PartialOrd + Address,
<T as Address>::Keys: PartialOrd,
<T as Address>::Target: PartialOrd,
impl<T> PartialOrd for Static<T>where
T: PartialOrd,
impl<T> PartialOrd for Cell<T>where
T: PartialOrd + Copy,
impl<T> PartialOrd for RefCell<T>where
T: PartialOrd + ?Sized,
impl<T> PartialOrd for PhantomContravariant<T>where
T: ?Sized,
impl<T> PartialOrd for PhantomCovariant<T>where
T: ?Sized,
impl<T> PartialOrd for PhantomInvariant<T>where
T: ?Sized,
impl<T> PartialOrd for ManuallyDrop<T>where
T: PartialOrd + ?Sized,
impl<T> PartialOrd for NonZero<T>where
T: ZeroablePrimitive + PartialOrd,
impl<T> PartialOrd for Saturating<T>where
T: PartialOrd,
impl<T> PartialOrd for Wrapping<T>where
T: PartialOrd,
impl<T> PartialOrd for Reverse<T>where
T: PartialOrd,
impl<T> PartialOrd for NonNull<T>where
T: ?Sized,
impl<T> PartialOrd for CapacityError<T>where
T: PartialOrd,
impl<T> PartialOrd for Hmac<T>where
T: PartialOrd + Hash,
impl<T> PartialOrd for bitcoin_hashes::sha256t::Hash<T>where
T: Tag,
impl<T> PartialOrd for MisalignError<T>where
T: PartialOrd,
impl<T> PartialOrd for DebugInfoOffset<T>where
T: PartialOrd,
impl<T> PartialOrd for DebugTypesOffset<T>where
T: PartialOrd,
impl<T> PartialOrd for UnitOffset<T>where
T: PartialOrd,
impl<T> PartialOrd for indexmap::set::slice::Slice<T>where
T: PartialOrd,
impl<T> PartialOrd for nonempty::nonzero::NonEmpty<T>where
T: PartialOrd,
impl<T> PartialOrd for nonempty::NonEmpty<T>where
T: PartialOrd,
impl<T> PartialOrd for TryWriteableInfallibleAsWriteable<T>where
T: PartialOrd,
impl<T> PartialOrd for WriteableAsTryWriteableInfallible<T>where
T: PartialOrd,
impl<T> PartialOrd for Unalign<T>where
T: Unaligned + PartialOrd,
impl<T> PartialOrd for ZeroSlice<T>where
T: AsULE + PartialOrd,
impl<T> PartialOrd<T> for OptionBound<T>where
T: PartialOrd,
impl<T, A1, A2> PartialOrd<Vec<T, A2>> for gclient::ext::sp_runtime::Vec<T, A1>
Implements comparison of vectors, lexicographically.
impl<T, A> PartialOrd for BTreeSet<T, A>
impl<T, A> PartialOrd for LinkedList<T, A>where
T: PartialOrd,
A: Allocator,
impl<T, A> PartialOrd for VecDeque<T, A>where
T: PartialOrd,
A: Allocator,
impl<T, A> PartialOrd for Rc<T, A>
impl<T, A> PartialOrd for UniqueRc<T, A>
impl<T, A> PartialOrd for gclient::ext::sp_core::sp_std::prelude::Box<T, A>
impl<T, A> PartialOrd for Arc<T, A>
impl<T, A> PartialOrd for UniqueArc<T, A>
impl<T, A> PartialOrd for allocator_api2::stable::boxed::Box<T, A>
impl<T, A> PartialOrd for allocator_api2::stable::vec::Vec<T, A>where
T: PartialOrd,
A: Allocator,
Implements comparison of vectors, lexicographically.
impl<T, B> PartialOrd for Ref<B, [T]>
impl<T, B> PartialOrd for Ref<B, T>
impl<T, BoundSelf, BoundRhs> PartialOrd<BoundedVec<T, BoundRhs>> for BoundedVec<T, BoundSelf>
impl<T, BoundSelf, BoundRhs> PartialOrd<BoundedVec<T, BoundRhs>> for WeakBoundedVec<T, BoundSelf>
impl<T, BoundSelf, BoundRhs> PartialOrd<WeakBoundedVec<T, BoundRhs>> for BoundedVec<T, BoundSelf>
impl<T, BoundSelf, BoundRhs> PartialOrd<WeakBoundedVec<T, BoundRhs>> for WeakBoundedVec<T, BoundSelf>
impl<T, D> PartialOrd for TypeWithDefault<T, D>where
T: PartialOrd,
D: Get<T>,
impl<T, E> PartialOrd for Result<T, E>where
T: PartialOrd,
E: PartialOrd,
impl<T, F> PartialOrd for VarZeroSlice<T, F>
impl<T, N> PartialOrd for GenericArray<T, N>where
T: PartialOrd,
N: ArrayLength<T>,
impl<T, O, Rhs> PartialOrd<Rhs> for BitBox<T, O>
tarpaulin_include only.impl<T, O, Rhs> PartialOrd<Rhs> for BitVec<T, O>
tarpaulin_include only.impl<T, S> PartialOrd for BoundedBTreeSet<T, S>
impl<T, U> PartialOrd<Exclusive<U>> for Exclusive<T>
impl<T, const CAP: usize> PartialOrd for arrayvec::arrayvec::ArrayVec<T, CAP>where
T: PartialOrd,
impl<T, const N: usize> PartialOrd for [T; N]where
T: PartialOrd,
Implements comparison of arrays lexicographically.
impl<T, const N: usize> PartialOrd for LimitedVec<T, N>where
T: PartialOrd,
impl<T, const N: usize> PartialOrd for Mask<T, N>
impl<T, const N: usize> PartialOrd for Simd<T, N>
Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.