pub fn decode_vec_with_len<T, I>( input: &mut I, len: usize, ) -> Result<Vec<T>, Error>where T: Decode, I: Input,
Decode the vec (without a prepended len).
This is equivalent to decode all elements one by one, but it is optimized in some situation.