pub struct Storage<T, Client>where
T: Config,{ /* private fields */ }Expand description
Query the runtime storage.
Implementations
Sourceimpl<T, Client> Storage<T, Client>where
T: Config,
Client: OnlineClientT<T>,
impl<T, Client> Storage<T, Client>where
T: Config,
Client: OnlineClientT<T>,
Sourcepub fn fetch_raw(
&self,
key: impl Into<Vec<u8>>,
) -> impl Future<Output = Result<Option<Vec<u8>>, Error>> + 'static
pub fn fetch_raw( &self, key: impl Into<Vec<u8>>, ) -> impl Future<Output = Result<Option<Vec<u8>>, Error>> + 'static
Fetch the raw encoded value at the key given.
Sourcepub fn fetch_raw_keys(
&self,
key: impl Into<Vec<u8>>,
) -> impl Future<Output = Result<StreamOf<Result<Vec<u8>, Error>>, Error>> + 'static
pub fn fetch_raw_keys( &self, key: impl Into<Vec<u8>>, ) -> impl Future<Output = Result<StreamOf<Result<Vec<u8>, Error>>, Error>> + 'static
Stream all of the raw keys underneath the key given
Sourcepub fn fetch<'address, Addr>(
&self,
address: &'address Addr,
) -> impl Future<Output = Result<Option<<Addr as Address>::Target>, Error>> + use<'address, Addr, Client, T>
pub fn fetch<'address, Addr>( &self, address: &'address Addr, ) -> impl Future<Output = Result<Option<<Addr as Address>::Target>, Error>> + use<'address, Addr, Client, T>
Fetch a decoded value from storage at a given address.
Example
use subxt::{ PolkadotConfig, OnlineClient };
#[subxt::subxt(runtime_metadata_path = "../artifacts/polkadot_metadata_full.scale")]
pub mod polkadot {}
let api = OnlineClient::<PolkadotConfig>::new().await.unwrap();
// Address to a storage entry we'd like to access.
let address = polkadot::storage().xcm_pallet().queries(12345);
// Fetch just the keys, returning up to 10 keys.
let value = api
.storage()
.at_latest()
.await
.unwrap()
.fetch(&address)
.await
.unwrap();
println!("Value: {:?}", value);Sourcepub fn fetch_or_default<'address, Addr>(
&self,
address: &'address Addr,
) -> impl Future<Output = Result<<Addr as Address>::Target, Error>> + use<'address, Addr, Client, T>
pub fn fetch_or_default<'address, Addr>( &self, address: &'address Addr, ) -> impl Future<Output = Result<<Addr as Address>::Target, Error>> + use<'address, Addr, Client, T>
Fetch a StorageKey that has a default value with an optional block hash.
Sourcepub fn iter<Addr>(
&self,
address: Addr,
) -> impl Future<Output = Result<StreamOf<Result<StorageKeyValuePair<Addr>, Error>>, Error>> + 'static
pub fn iter<Addr>( &self, address: Addr, ) -> impl Future<Output = Result<StreamOf<Result<StorageKeyValuePair<Addr>, Error>>, Error>> + 'static
Returns an iterator of key value pairs.
use subxt::{ PolkadotConfig, OnlineClient };
#[subxt::subxt(runtime_metadata_path = "../artifacts/polkadot_metadata_full.scale")]
pub mod polkadot {}
let api = OnlineClient::<PolkadotConfig>::new().await.unwrap();
// Address to the root of a storage entry that we'd like to iterate over.
let address = polkadot::storage().xcm_pallet().version_notifiers_iter();
// Iterate over keys and values at that address.
let mut iter = api
.storage()
.at_latest()
.await
.unwrap()
.iter(address)
.await
.unwrap();
while let Some(Ok(kv)) = iter.next().await {
println!("Key bytes: 0x{}", hex::encode(&kv.key_bytes));
println!("Value: {}", kv.value);
}Trait Implementations