Error

Type Alias Error 

pub type Error = Error;
The Error enum of this pallet.

Aliased Type

pub enum Error {
    TooMany,
    NotFound,
    NotProxy,
    Unproxyable,
    Duplicate,
    NoPermission,
    Unannounced,
    NoSelfProxy,
}

Variants



TooMany

There are too many proxies registered or too many announcements pending.



NotFound

Proxy registration not found.



NotProxy

Sender is not a proxy of the account to be proxied.



Unproxyable

A call which is incompatible with the proxy type’s filter was attempted.



Duplicate

Account is already a proxy.



NoPermission

Call may not be made by proxy because it may escalate its privileges.



Unannounced

Announcement, if made at all, was made too recently.



NoSelfProxy

Cannot add self as proxy.