Event

Type Alias Event 

pub type Event = Event;
The Event enum of this pallet

Aliased Type

pub enum Event {
    NewSession {
        session_index: u32,
    },
}

Variants



NewSession

New session has happened. Note that the argument is the session index, not the block number as the type might suggest.

Fields

session_index: u32