pub trait Hash {
// Required method
fn hash<H>(&self, state: &mut H)
where H: Hasher;
// Provided method
fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher,
Self: Sized { ... }
}Expand description
A hashable type.
Types implementing Hash are able to be hashed with an instance of
Hasher.
Implementing Hash
You can derive Hash with #[derive(Hash)] if all fields implement Hash.
The resulting hash will be the combination of the values from calling
hash on each field.
#[derive(Hash)]
struct Rustacean {
name: String,
country: String,
}If you need more control over how a value is hashed, you can of course
implement the Hash trait yourself:
use std::hash::{Hash, Hasher};
struct Person {
id: u32,
name: String,
phone: u64,
}
impl Hash for Person {
fn hash<H: Hasher>(&self, state: &mut H) {
self.id.hash(state);
self.phone.hash(state);
}
}Hash and Eq
When implementing both Hash and Eq, it is important that the following
property holds:
k1 == k2 -> hash(k1) == hash(k2)In other words, if two keys are equal, their hashes must also be equal.
HashMap and HashSet both rely on this behavior.
Thankfully, you won’t need to worry about upholding this property when
deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].
Violating this property is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Prefix collisions
Implementations of hash should ensure that the data they
pass to the Hasher are prefix-free. That is,
values which are not equal should cause two different sequences of values to be written,
and neither of the two sequences should be a prefix of the other.
For example, the standard implementation of Hash for &str passes an extra
0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.
Portability
Due to differences in endianness and type sizes, data fed by Hash to a Hasher
should not be considered portable across platforms. Additionally the data passed by most
standard library types should not be considered stable between compiler versions.
This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and
instead should check consistency with Eq.
Serialization formats intended to be portable between platforms or compiler versions should
either avoid encoding hashes or only rely on Hash and Hasher implementations that
provide additional guarantees.
Required Methods
Provided Methods
1.3.0 · Sourcefn hash_slice<H>(data: &[Self], state: &mut H)
fn hash_slice<H>(data: &[Self], state: &mut H)
Feeds a slice of this type into the given Hasher.
This method is meant as a convenience, but its implementation is
also explicitly left unspecified. It isn’t guaranteed to be
equivalent to repeated calls of hash and implementations of
Hash should keep that in mind and call hash themselves
if the slice isn’t treated as a whole unit in the PartialEq
implementation.
For example, a VecDeque implementation might naïvely call
as_slices and then hash_slice on each slice, but this
is wrong since the two slices can change with a call to
make_contiguous without affecting the PartialEq
result. Since these slices aren’t treated as singular
units, and instead part of a larger deque, this method cannot
be used.
Examples
use std::hash::{DefaultHasher, Hash, Hasher};
let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Hash for InstrumentationStatus
impl Hash for DispatchKind
impl Hash for MessageDetails
impl Hash for ErrorReplyReason
impl Hash for ExecutionError
impl Hash for ExtError
impl Hash for MemoryError
impl Hash for MessageError
impl Hash for ReplyCode
impl Hash for ReservationError
impl Hash for SignalCode
impl Hash for SimpleExecutionError
impl Hash for SuccessReplyReason
impl Hash for PolkadotConfig
impl Hash for SubstrateConfig
impl Hash for gclient::ext::subxt::ext::futures::io::ErrorKind
impl Hash for PollNext
impl Hash for gclient::ext::subxt::ext::jsonrpsee::core::JsonValue
impl Hash for TransactionVersion
impl Hash for DeriveJunction
impl Hash for OffchainOverlayedChange
impl Hash for ChildInfo
impl Hash for gclient::ext::sp_core::sp_std::cmp::Ordering
impl Hash for Infallible
impl Hash for IntErrorKind
impl Hash for gclient::ext::sp_core::sp_std::sync::atomic::Ordering
impl Hash for AsciiChar
impl Hash for core::net::ip_addr::IpAddr
impl Hash for Ipv6MulticastScope
impl Hash for SocketAddr
impl Hash for CheckedCastError
impl Hash for PodCastError
impl Hash for byteorder::BigEndian
impl Hash for byteorder::LittleEndian
impl Hash for ExtrinsicType
impl Hash for HashType
impl Hash for ParamType
impl Hash for RegularParamType
impl Hash for SyscallName
impl Hash for SyscallSignature
impl Hash for ErrPtr
impl Hash for Ptr
impl Hash for Format
impl Hash for SectionId
impl Hash for RunTimeEndian
impl Hash for Case
impl Hash for HexToArrayError
impl Hash for HexToBytesError
impl Hash for ExtensionType
impl Hash for GeneralCategory
impl Hash for BufferFormat
impl Hash for fsconfig_command
impl Hash for membarrier_cmd
impl Hash for membarrier_cmd_flag
impl Hash for log::Level
impl Hash for log::LevelFilter
impl Hash for DataFormat
impl Hash for MZError
impl Hash for MZFlush
impl Hash for MZStatus
impl Hash for TINFLStatus
impl Hash for num_format::error_kind::ErrorKind
impl Hash for Grouping
impl Hash for num_format::locale::Locale
impl Hash for AddressSize
impl Hash for Architecture
impl Hash for BinaryFormat
impl Hash for ComdatKind
impl Hash for FileFlags
impl Hash for RelocationEncoding
impl Hash for RelocationKind
impl Hash for SectionFlags
impl Hash for SectionKind
impl Hash for object::common::SegmentFlags
impl Hash for SubArchitecture
impl Hash for SymbolKind
impl Hash for SymbolScope
impl Hash for Endianness
impl Hash for ArchiveKind
impl Hash for ImportType
impl Hash for CompressionFormat
impl Hash for FileKind
impl Hash for ObjectKind
impl Hash for RelocationTarget
impl Hash for SymbolSection
impl Hash for parity_bip39::language::Language
impl Hash for Direction
impl Hash for rustls_pki_types::server_name::IpAddr
impl Hash for MultiSignatureStage
impl Hash for SignatureError
impl Hash for All
impl Hash for SignOnly
impl Hash for VerifyOnly
impl Hash for ElligatorSwiftParty
impl Hash for secp256k1::Error
impl Hash for Parity
impl Hash for OpCode
impl Hash for Data
impl Hash for TokenRegistry
impl Hash for Month
impl Hash for Weekday
impl Hash for uint::uint::FromStrRadixErrKind
impl Hash for uint::uint::FromStrRadixErrKind
impl Hash for Origin
impl Hash for ExportKind
impl Hash for wasm_encoder::core::types::AbstractHeapType
impl Hash for wasm_encoder::core::types::HeapType
impl Hash for wasm_encoder::core::types::StorageType
impl Hash for wasm_encoder::core::types::ValType
impl Hash for ComdatSymbolKind
impl Hash for wasmparser::readers::core::operators::Ordering
impl Hash for RelocAddendKind
impl Hash for RelocationType
impl Hash for wasmparser::readers::core::types::AbstractHeapType
impl Hash for CompositeInnerType
impl Hash for wasmparser::readers::core::types::HeapType
impl Hash for wasmparser::readers::core::types::StorageType
impl Hash for UnpackedIndex
impl Hash for wasmparser::readers::core::types::ValType
impl Hash for bool
impl Hash for char
impl Hash for i8
impl Hash for i16
impl Hash for i32
impl Hash for i64
impl Hash for i128
impl Hash for isize
impl Hash for !
impl Hash for str
impl Hash for u8
impl Hash for u16
impl Hash for u32
impl Hash for u64
impl Hash for u128
impl Hash for ()
impl Hash for usize
impl Hash for PanicBuffer
impl Hash for CodeMetadata
impl Hash for InstantiatedSectionSizes
impl Hash for InstrumentedCode
impl Hash for ActorId
impl Hash for CodeId
impl Hash for MessageId
impl Hash for ReservationId
impl Hash for LimitedStrError
impl Hash for PageBuf
impl Hash for ContextStore
impl Hash for ReplyDetails
impl Hash for SignalDetails
impl Hash for StoredDelayedDispatch
impl Hash for StoredDispatch
impl Hash for StoredMessage
impl Hash for UserMessage
impl Hash for UserStoredMessage
impl Hash for MemoryInfix
impl Hash for ReservationNonce
impl Hash for ReplyInfo
impl Hash for gclient::ext::sp_runtime::app_crypto::ecdsa::AppPublic
impl Hash for gclient::ext::sp_runtime::app_crypto::ecdsa::AppSignature
impl Hash for gclient::ext::sp_runtime::app_crypto::ed25519::AppPublic
impl Hash for gclient::ext::sp_runtime::app_crypto::ed25519::AppSignature
impl Hash for gclient::ext::sp_runtime::app_crypto::sr25519::AppPublic
impl Hash for gclient::ext::sp_runtime::app_crypto::sr25519::AppSignature
impl Hash for gclient::ext::sp_runtime::scale_info::prelude::time::Instant
impl Hash for SystemTime
impl Hash for MetaType
impl Hash for AccountId32
impl Hash for CryptoTypeId
impl Hash for KeyTypeId
impl Hash for TestSignature
impl Hash for UintAuthorityId
impl Hash for gclient::ext::subxt::backend::chain_head::rpc_methods::Bytes
impl Hash for gclient::ext::subxt::config::polkadot::U256
impl Hash for Uri
impl Hash for Url
URLs hash like their serialization.
impl Hash for HeaderValue
impl Hash for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::H128
impl Hash for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::H384
impl Hash for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::H768
impl Hash for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::U128
impl Hash for gclient::ext::subxt::ext::scale_decode::ext::primitive_types::U512
impl Hash for gclient::ext::subxt::ext::subxt_rpcs::methods::chain_head::Bytes
impl Hash for gclient::ext::subxt::utils::H160
impl Hash for gclient::ext::subxt::utils::H256
impl Hash for gclient::ext::subxt::utils::H512
impl Hash for ByteStr
impl Hash for ByteString
impl Hash for CString
impl Hash for String
impl Hash for Capabilities
impl Hash for HttpRequestId
impl Hash for ChildTrieParentKeyId
impl Hash for PrefixedStorageKey
impl Hash for StorageData
impl Hash for StorageKey
impl Hash for TrackedStorageKey
impl Hash for gclient::ext::sp_core::Bytes
impl Hash for gclient::ext::sp_core::H160
impl Hash for gclient::ext::sp_core::H256
impl Hash for gclient::ext::sp_core::H512
impl Hash for gclient::ext::sp_core::U256
impl Hash for gclient::ext::sp_core::U512
impl Hash for Layout
impl Hash for TypeId
impl Hash for PhantomPinned
impl Hash for RangeFull
impl Hash for gclient::ext::sp_core::sp_std::time::Duration
impl Hash for CStr
impl Hash for core::fmt::Error
impl Hash for core::net::ip_addr::Ipv4Addr
impl Hash for core::net::ip_addr::Ipv6Addr
impl Hash for SocketAddrV4
impl Hash for SocketAddrV6
impl Hash for Location<'_>
impl Hash for Alignment
impl Hash for OsStr
impl Hash for OsString
impl Hash for FileType
impl Hash for std::os::unix::net::ucred::UCred
impl Hash for Path
impl Hash for PathBuf
impl Hash for PrefixComponent<'_>
impl Hash for ThreadId
impl Hash for aho_corasick::util::primitives::PatternID
impl Hash for aho_corasick::util::primitives::StateID
impl Hash for aho_corasick::util::search::Match
impl Hash for aho_corasick::util::search::Span
impl Hash for bitcoin_hashes::hash160::Hash
impl Hash for bitcoin_hashes::ripemd160::Hash
impl Hash for bitcoin_hashes::sha1::Hash
impl Hash for bitcoin_hashes::sha256::Hash
impl Hash for Midstate
impl Hash for bitcoin_hashes::sha256d::Hash
impl Hash for bitcoin_hashes::sha512::Hash
impl Hash for bitcoin_hashes::sha512_256::Hash
impl Hash for bitcoin_hashes::siphash24::Hash
impl Hash for Lsb0
impl Hash for Msb0
impl Hash for bytes::bytes::Bytes
impl Hash for BytesMut
impl Hash for ObjectIdentifier
impl Hash for CompressedEdwardsY
impl Hash for MontgomeryPoint
impl Hash for CompressedRistretto
impl Hash for curve25519_dalek::scalar::Scalar
impl Hash for VerifyingKey
impl Hash for VerificationKeyBytes
impl Hash for FallibleSyscallSignature
impl Hash for InfallibleSyscallSignature
impl Hash for SystemSyscallSignature
impl Hash for DebugTypeSignature
impl Hash for DwoId
impl Hash for Encoding
impl Hash for LineEncoding
impl Hash for Register
impl Hash for DwAccess
impl Hash for DwAddr
impl Hash for DwAt
impl Hash for DwAte
impl Hash for DwCc
impl Hash for DwCfa
impl Hash for DwChildren
impl Hash for DwDefaulted
impl Hash for DwDs
impl Hash for DwDsc
impl Hash for DwEhPe
impl Hash for DwEnd
impl Hash for DwForm
impl Hash for DwId
impl Hash for DwIdx
impl Hash for DwInl
impl Hash for DwLang
impl Hash for DwLle
impl Hash for DwLnct
impl Hash for DwLne
impl Hash for DwLns
impl Hash for DwMacro
impl Hash for DwOp
impl Hash for DwOrd
impl Hash for DwRle
impl Hash for DwSect
impl Hash for DwSectV2
impl Hash for DwTag
impl Hash for DwUt
impl Hash for DwVirtuality
impl Hash for DwVis
impl Hash for gimli::endianity::BigEndian
impl Hash for gimli::endianity::LittleEndian
impl Hash for gimli::read::rnglists::Range
impl Hash for NonZeroU256
impl Hash for FailedPage
impl Hash for StreamId
impl Hash for HeaderName
impl Hash for Method
impl Hash for StatusCode
impl Hash for Authority
Case-insensitive hashing
Examples
let a: Authority = "HELLO.com".parse().unwrap();
let b: Authority = "hello.coM".parse().unwrap();
let mut s = DefaultHasher::new();
a.hash(&mut s);
let a = s.finish();
let mut s = DefaultHasher::new();
b.hash(&mut s);
let b = s.finish();
assert_eq!(a, b);impl Hash for PathAndQuery
impl Hash for Scheme
Case-insensitive hashing
impl Hash for Version
impl Hash for Name
impl Hash for ReasonPhrase
impl Hash for DataLocale
impl Hash for Other
impl Hash for icu_locale_core::extensions::private::other::Subtag
impl Hash for Private
impl Hash for Extensions
impl Hash for Fields
impl Hash for icu_locale_core::extensions::transform::key::Key
impl Hash for Transform
impl Hash for icu_locale_core::extensions::transform::value::Value
impl Hash for Attribute
impl Hash for Attributes
impl Hash for icu_locale_core::extensions::unicode::key::Key
impl Hash for Keywords
impl Hash for Unicode
impl Hash for SubdivisionId
impl Hash for SubdivisionSuffix
impl Hash for icu_locale_core::extensions::unicode::value::Value
impl Hash for LanguageIdentifier
impl Hash for icu_locale_core::locale::Locale
impl Hash for CurrencyType
impl Hash for NumberingSystem
impl Hash for RegionOverride
impl Hash for RegionalSubdivision
impl Hash for TimeZoneShortId
impl Hash for LocalePreferences
impl Hash for icu_locale_core::subtags::language::Language
impl Hash for Region
impl Hash for icu_locale_core::subtags::script::Script
impl Hash for icu_locale_core::subtags::Subtag
impl Hash for Variant
impl Hash for Variants
impl Hash for BidiClass
impl Hash for CanonicalCombiningClass
impl Hash for EastAsianWidth
impl Hash for GeneralCategoryOutOfBoundsError
impl Hash for GraphemeClusterBreak
impl Hash for HangulSyllableType
impl Hash for IndicSyllabicCategory
impl Hash for JoiningType
impl Hash for LineBreak
impl Hash for icu_properties::props::Script
impl Hash for SentenceBreak
impl Hash for VerticalOrientation
impl Hash for WordBreak
impl Hash for DataMarkerId
impl Hash for DataMarkerIdHash
impl Hash for DataMarkerInfo
impl Hash for DataMarkerAttributes
impl Hash for StreamResult
impl Hash for mio::token::Token
impl Hash for CustomFormat
impl Hash for CustomFormatBuilder
impl Hash for num_format::error::Error
impl Hash for object::endian::BigEndian
impl Hash for object::endian::LittleEndian
impl Hash for CompressedFileRange
impl Hash for SectionIndex
impl Hash for SymbolIndex
impl Hash for Mnemonic
impl Hash for PotentialCodePoint
impl Hash for primitive_types::H128
impl Hash for primitive_types::H384
impl Hash for primitive_types::H768
impl Hash for primitive_types::U128
impl Hash for LazyStateID
impl Hash for Transition
impl Hash for NonMaxUsize
impl Hash for regex_automata::util::primitives::PatternID
impl Hash for SmallIndex
impl Hash for regex_automata::util::primitives::StateID
impl Hash for HalfMatch
impl Hash for regex_automata::util::search::Match
impl Hash for regex_automata::util::search::Span
impl Hash for CreateFlags
impl Hash for ReadFlags
impl Hash for WatchFlags
impl Hash for Access
impl Hash for AtFlags
impl Hash for FallocateFlags
impl Hash for MemfdFlags
impl Hash for Mode
impl Hash for OFlags
impl Hash for RenameFlags
impl Hash for ResolveFlags
impl Hash for SealFlags
impl Hash for StatVfsMountFlags
impl Hash for StatxFlags
impl Hash for Errno
impl Hash for DupFlags
impl Hash for FdFlags
impl Hash for ReadWriteFlags
impl Hash for MountFlags
impl Hash for MountPropagationFlags
impl Hash for UnmountFlags
impl Hash for XattrFlags
impl Hash for Opcode
impl Hash for Gid
impl Hash for Uid
impl Hash for rustls_pki_types::server_name::Ipv4Addr
impl Hash for rustls_pki_types::server_name::Ipv6Addr
impl Hash for UnixTime
impl Hash for AdaptorCertPublic
impl Hash for ChainCode
impl Hash for schnorrkel::keys::PublicKey
impl Hash for RistrettoBoth
impl Hash for VRFInOut
impl Hash for VRFPreOut
impl Hash for secp256k1_sys::recovery::RecoverableSignature
secp256k1_fuzz only.impl Hash for secp256k1_sys::ElligatorSwift
impl Hash for secp256k1_sys::Keypair
secp256k1_fuzz only.impl Hash for secp256k1_sys::PublicKey
secp256k1_fuzz only.impl Hash for secp256k1_sys::Signature
secp256k1_fuzz only.impl Hash for secp256k1_sys::XOnlyPublicKey
secp256k1_fuzz only.impl Hash for secp256k1::ecdsa::recovery::RecoverableSignature
impl Hash for SerializedSignature
impl Hash for secp256k1::ecdsa::Signature
impl Hash for secp256k1::ellswift::ElligatorSwift
impl Hash for InvalidParityValue
impl Hash for secp256k1::key::Keypair
impl Hash for secp256k1::key::PublicKey
impl Hash for secp256k1::key::XOnlyPublicKey
impl Hash for OutOfRangeError
impl Hash for secp256k1::scalar::Scalar
impl Hash for secp256k1::schnorr::Signature
impl Hash for Message
impl Hash for Map<String, Value>
impl Hash for Number
impl Hash for socket2::sockaddr::SockAddr
impl Hash for socket2::sockaddr::SockAddr
impl Hash for CloseReason
impl Hash for ss58_registry::token::Token
impl Hash for TokenAmount
impl Hash for Date
impl Hash for time::duration::Duration
impl Hash for ComponentRange
impl Hash for time::instant::Instant
impl Hash for OffsetDateTime
impl Hash for PrimitiveDateTime
impl Hash for Time
impl Hash for UtcOffset
impl Hash for AnyDelimiterCodec
impl Hash for BytesCodec
impl Hash for LinesCodec
impl Hash for tokio::net::unix::ucred::UCred
impl Hash for tokio::runtime::task::id::Id
impl Hash for tokio::time::instant::Instant
impl Hash for Identifier
impl Hash for Field
impl Hash for tracing_core::metadata::Level
impl Hash for tracing_core::metadata::LevelFilter
impl Hash for tracing_core::span::Id
impl Hash for tracing::span::Span
impl Hash for trie_db::Bytes
impl Hash for ATerm
impl Hash for B0
impl Hash for B1
impl Hash for Z0
impl Hash for Equal
impl Hash for Greater
impl Hash for Less
impl Hash for UTerm
impl Hash for OpaqueOrigin
impl Hash for wasm_encoder::core::code::Ieee32
impl Hash for wasm_encoder::core::code::Ieee64
impl Hash for wasm_encoder::core::globals::GlobalType
impl Hash for wasm_encoder::core::memories::MemoryType
impl Hash for wasm_encoder::core::tables::TableType
impl Hash for wasm_encoder::core::types::ArrayType
impl Hash for wasm_encoder::core::types::ContType
impl Hash for wasm_encoder::core::types::FieldType
impl Hash for wasm_encoder::core::types::FuncType
impl Hash for wasm_encoder::core::types::RefType
impl Hash for wasm_encoder::core::types::StructType
impl Hash for WasmFeatures
impl Hash for wasmparser::readers::core::linking::SegmentFlags
impl Hash for wasmparser::readers::core::linking::SymbolFlags
impl Hash for wasmparser::readers::core::operators::Ieee32
impl Hash for wasmparser::readers::core::operators::Ieee64
impl Hash for V128
impl Hash for RelocationEntry
impl Hash for wasmparser::readers::core::types::ArrayType
impl Hash for CompositeType
impl Hash for wasmparser::readers::core::types::ContType
impl Hash for wasmparser::readers::core::types::FieldType
impl Hash for wasmparser::readers::core::types::FuncType
impl Hash for wasmparser::readers::core::types::GlobalType
impl Hash for wasmparser::readers::core::types::MemoryType
impl Hash for PackedIndex
impl Hash for RecGroup
impl Hash for wasmparser::readers::core::types::RefType
impl Hash for wasmparser::readers::core::types::StructType
impl Hash for SubType
impl Hash for wasmparser::readers::core::types::TableType
impl Hash for ValidatorId
impl Hash for CoreTypeId
impl Hash for RecGroupId
impl Hash for Const
impl Hash for Mut
impl Hash for NullPtrError
impl Hash for SliceTokensLocation
impl Hash for StrTokensLocation
impl Hash for CharULE
impl Hash for Index8
impl Hash for Index16
impl Hash for Index32
impl<'a> Hash for gclient::ext::subxt::ext::jsonrpsee::http_client::types::Id<'a>
impl<'a> Hash for SubscriptionId<'a>
impl<'a> Hash for Component<'a>
impl<'a> Hash for Prefix<'a>
impl<'a> Hash for ServerName<'a>
impl<'a> Hash for Incoming<'a>
impl<'a> Hash for PhantomContravariantLifetime<'a>
impl<'a> Hash for PhantomCovariantLifetime<'a>
impl<'a> Hash for PhantomInvariantLifetime<'a>
impl<'a> Hash for Metadata<'a>
impl<'a> Hash for MetadataBuilder<'a>
impl<'a> Hash for DecimalStr<'a>
impl<'a> Hash for InfinityStr<'a>
impl<'a> Hash for MinusSignStr<'a>
impl<'a> Hash for NanStr<'a>
impl<'a> Hash for PlusSignStr<'a>
impl<'a> Hash for SeparatorStr<'a>
impl<'a> Hash for Ident<'a>
impl<'a> Hash for password_hash::value::Value<'a>
impl<'a> Hash for DnsName<'a>
impl<'a> Hash for CertificateDer<'a>
impl<'a> Hash for CertificateRevocationListDer<'a>
impl<'a> Hash for CertificateSigningRequestDer<'a>
impl<'a> Hash for Der<'a>
impl<'a> Hash for EchConfigListBytes<'a>
impl<'a> Hash for SubjectPublicKeyInfoDer<'a>
impl<'a> Hash for TrustAnchor<'a>
impl<'a> Hash for BinaryReader<'a>
impl<'a, M, T, O> Hash for PartialElement<'a, M, T, O>
tarpaulin_include only.impl<'a, T, S> Hash for BoundedSlice<'a, T, S>where
T: Hash,
std only.impl<'a, const N: usize> Hash for LimitedStr<'a, N>
impl<'buf> Hash for AllPreallocated<'buf>
impl<'buf> Hash for SignOnlyPreallocated<'buf>
impl<'buf> Hash for VerifyOnlyPreallocated<'buf>
impl<'data> Hash for CompressedData<'data>
impl<'data> Hash for ObjectMapEntry<'data>
impl<'data> Hash for SymbolMapName<'data>
impl<'input, Endian> Hash for EndianSlice<'input, Endian>
impl<'s, T> Hash for SliceVec<'s, T>where
T: Hash,
impl<A> Hash for TinyVec<A>
impl<A> Hash for SmallVec<A>
impl<A> Hash for tinyvec::arrayvec::ArrayVec<A>
impl<A, B> Hash for EitherOrBoth<A, B>
impl<A, O> Hash for BitArray<A, O>where
A: BitViewSized,
O: BitOrder,
tarpaulin_include only.impl<AccountId, AccountIndex> Hash for MultiAddress<AccountId, AccountIndex>
impl<B> Hash for Cow<'_, B>
impl<B, C> Hash for ControlFlow<B, C>
impl<DataStruct> Hash for ErasedMarker<DataStruct>
impl<Dyn> Hash for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<E> Hash for I16Bytes<E>
impl<E> Hash for I32Bytes<E>
impl<E> Hash for I64Bytes<E>
impl<E> Hash for U16Bytes<E>
impl<E> Hash for U32Bytes<E>
impl<E> Hash for U64Bytes<E>
impl<F> Hash for Fwhere
F: FnPtr,
impl<H> Hash for BlockRef<H>where
H: Hash,
impl<Idx> Hash for gclient::ext::sp_core::sp_std::ops::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for gclient::ext::sp_core::sp_std::ops::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for gclient::ext::sp_core::sp_std::ops::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for RangeTo<Idx>where
Idx: Hash,
impl<Idx> Hash for gclient::ext::sp_core::sp_std::ops::RangeToInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeToInclusive<Idx>where
Idx: Hash,
impl<Inner> Hash for Frozen<Inner>where
Inner: Hash + Mutability,
impl<K> Hash for ExtendedKey<K>where
K: Hash,
impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
impl<K, V, A> Hash for BTreeMap<K, V, A>
impl<K, V, S> Hash for BoundedBTreeMap<K, V, S>
std only.impl<K, V, S> Hash for LiteMap<K, V, S>
impl<L, R> Hash for Either<L, R>
impl<M, T> Hash for Address<M, T>where
M: Mutability,
T: ?Sized,
impl<M, T, O> Hash for BitRef<'_, M, T, O>
tarpaulin_include only.impl<M, T, O> Hash for BitPtrRange<M, T, O>
tarpaulin_include only.impl<M, T, O> Hash for BitPtr<M, T, O>
tarpaulin_include only.impl<Ptr> Hash for Pin<Ptr>
impl<R> Hash for BitEnd<R>where
R: Hash + BitRegister,
impl<R> Hash for BitIdx<R>where
R: Hash + BitRegister,
impl<R> Hash for BitIdxError<R>where
R: Hash + BitRegister,
impl<R> Hash for BitMask<R>where
R: Hash + BitRegister,
impl<R> Hash for BitPos<R>where
R: Hash + BitRegister,
impl<R> Hash for BitSel<R>where
R: Hash + BitRegister,
impl<R> Hash for LocationListEntry<R>
impl<R> Hash for Expression<R>
impl<RFM, SD, SUM> Hash for ScheduledTask<RFM, SD, SUM>
impl<S> Hash for Host<S>where
S: Hash,
impl<Section, Symbol> Hash for object::common::SymbolFlags<Section, Symbol>
impl<Storage> Hash for __BindgenBitfieldUnit<Storage>where
Storage: Hash,
impl<T> Hash for Poll<T>where
T: Hash,
impl<T> Hash for Bound<T>where
T: Hash,
impl<T> Hash for Option<T>where
T: Hash,
impl<T> Hash for BitPtrError<T>
impl<T> Hash for BitSpanError<T>
impl<T> Hash for UnitSectionOffset<T>where
T: Hash,
impl<T> Hash for *const Twhere
T: ?Sized,
impl<T> Hash for *mut Twhere
T: ?Sized,
impl<T> Hash for &T
impl<T> Hash for &mut T
impl<T> Hash for [T]where
T: Hash,
impl<T> Hash for (T₁, T₂, …, Tₙ)where
T: Hash,
This trait is implemented for tuples up to twelve items long.
impl<T> Hash for IntervalsTree<T>where
T: Hash,
impl<T> Hash for PhantomData<T>where
T: ?Sized,
impl<T> Hash for AllowStdIo<T>where
T: Hash,
impl<T> Hash for Static<T>where
T: Hash,
impl<T> Hash for WrapperKeepOpaque<T>
impl<T> Hash for PhantomContravariant<T>where
T: ?Sized,
impl<T> Hash for PhantomCovariant<T>where
T: ?Sized,
impl<T> Hash for PhantomInvariant<T>where
T: ?Sized,
impl<T> Hash for Discriminant<T>
impl<T> Hash for ManuallyDrop<T>
impl<T> Hash for NonZero<T>where
T: ZeroablePrimitive + Hash,
impl<T> Hash for Saturating<T>where
T: Hash,
impl<T> Hash for Wrapping<T>where
T: Hash,
impl<T> Hash for Reverse<T>where
T: Hash,
impl<T> Hash for Exclusive<T>
impl<T> Hash for NonNull<T>where
T: ?Sized,
impl<T> Hash for Hmac<T>
impl<T> Hash for bitcoin_hashes::sha256t::Hash<T>where
T: Tag,
impl<T> Hash for MisalignError<T>where
T: Hash,
impl<T> Hash for DebugAbbrevOffset<T>where
T: Hash,
impl<T> Hash for DebugFrameOffset<T>where
T: Hash,
impl<T> Hash for DebugInfoOffset<T>where
T: Hash,
impl<T> Hash for DebugMacinfoOffset<T>where
T: Hash,
impl<T> Hash for DebugMacroOffset<T>where
T: Hash,
impl<T> Hash for DebugTypesOffset<T>where
T: Hash,
impl<T> Hash for EhFrameOffset<T>where
T: Hash,
impl<T> Hash for LocationListsOffset<T>where
T: Hash,
impl<T> Hash for RangeListsOffset<T>where
T: Hash,
impl<T> Hash for RawRangeListsOffset<T>where
T: Hash,
impl<T> Hash for UnitOffset<T>where
T: Hash,
impl<T> Hash for indexmap::set::slice::Slice<T>where
T: Hash,
impl<T> Hash for nonempty::nonzero::NonEmpty<T>where
T: Hash,
impl<T> Hash for nonempty::NonEmpty<T>where
T: Hash,
impl<T> Hash for TryWriteableInfallibleAsWriteable<T>where
T: Hash,
impl<T> Hash for WriteableAsTryWriteableInfallible<T>where
T: Hash,
impl<T> Hash for Unalign<T>
impl<T, A> Hash for gclient::ext::sp_runtime::Vec<T, A>
The hash of a vector is the same as that of the corresponding slice,
as required by the core::borrow::Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));impl<T, A> Hash for BTreeSet<T, A>
impl<T, A> Hash for LinkedList<T, A>
impl<T, A> Hash for VecDeque<T, A>
impl<T, A> Hash for Rc<T, A>
impl<T, A> Hash for UniqueRc<T, A>
impl<T, A> Hash for gclient::ext::sp_core::sp_std::prelude::Box<T, A>
impl<T, A> Hash for Arc<T, A>
impl<T, A> Hash for UniqueArc<T, A>
impl<T, A> Hash for allocator_api2::stable::boxed::Box<T, A>
impl<T, A> Hash for allocator_api2::stable::vec::Vec<T, A>
The hash of a vector is the same as that of the corresponding slice,
as required by the core::borrow::Borrow implementation.
#![feature(build_hasher_simple_hash_one)]
use std::hash::BuildHasher;
let b = std::collections::hash_map::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));impl<T, E> Hash for Result<T, E>
impl<T, N> Hash for GenericArray<T, N>where
T: Hash,
N: ArrayLength<T>,
impl<T, O> Hash for BitBox<T, O>
tarpaulin_include only.impl<T, O> Hash for BitSlice<T, O>
tarpaulin_include only.impl<T, O> Hash for BitVec<T, O>
tarpaulin_include only.impl<T, S> Hash for BoundedBTreeSet<T, S>where
T: Hash,
std only.impl<T, S> Hash for BoundedVec<T, S>where
T: Hash,
std only.impl<T, const CAP: usize> Hash for arrayvec::arrayvec::ArrayVec<T, CAP>where
T: Hash,
impl<T, const N: usize> Hash for [T; N]where
T: Hash,
The hash of an array is the same as that of the corresponding slice,
as required by the Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));