WrapperTypeEncode

Trait WrapperTypeEncode 

pub trait WrapperTypeEncode: Deref { }
A marker trait for types that wrap other encodable type.

Such types should not carry any additional information that would require to be encoded, because the encoding is assumed to be the same as the wrapped type.

The wrapped type that is referred to is the Deref::Target.

Implementations on Foreign Types

Source

impl WrapperTypeEncode for Bytes

Source

impl<T> WrapperTypeEncode for &T
where T: ?Sized,

Source

impl<T> WrapperTypeEncode for &mut T
where T: ?Sized,

Implementors

Source

impl WrapperTypeEncode for String

Source

impl WrapperTypeEncode for gclient::ext::sp_core::Bytes

Source

impl<T> WrapperTypeEncode for Cow<'_, T>
where T: ToOwned + ?Sized,

Source

impl<T> WrapperTypeEncode for Rc<T>
where T: ?Sized,

Source

impl<T> WrapperTypeEncode for Box<T>
where T: ?Sized,

Source

impl<T> WrapperTypeEncode for Arc<T>
where T: ?Sized,

Source

impl<T> WrapperTypeEncode for Vec<T>

Source

impl<T, U> WrapperTypeEncode for Ref<'_, T, U>
where T: EncodeLike<U>, U: Encode,