pub type Error = Error;Expand description
The Error enum of this pallet.
Aliased Type
pub enum Error {
Show 26 variants
TooManySubAccounts,
NotFound,
NotNamed,
EmptyIndex,
FeeChanged,
NoIdentity,
StickyJudgement,
JudgementGiven,
InvalidJudgement,
InvalidIndex,
InvalidTarget,
TooManyRegistrars,
AlreadyClaimed,
NotSub,
NotOwned,
JudgementForDifferentIdentity,
JudgementPaymentFailed,
InvalidSuffix,
NotUsernameAuthority,
NoAllocation,
InvalidSignature,
RequiresSignature,
InvalidUsername,
UsernameTaken,
NoUsername,
NotExpired,
}Variants
TooManySubAccounts
Too many subs-accounts.
NotFound
Account isn’t found.
NotNamed
Account isn’t named.
EmptyIndex
Empty index.
FeeChanged
Fee is changed.
NoIdentity
No identity found.
StickyJudgement
Sticky judgement.
JudgementGiven
Judgement given.
InvalidJudgement
Invalid judgement.
InvalidIndex
The index is invalid.
InvalidTarget
The target is invalid.
TooManyRegistrars
Maximum amount of registrars reached. Cannot add any more.
AlreadyClaimed
Account ID is already named.
NotSub
Sender is not a sub-account.
NotOwned
Sub-account isn’t owned by sender.
JudgementForDifferentIdentity
The provided judgement was for a different identity.
JudgementPaymentFailed
Error that occurs when there is an issue paying for judgement.
InvalidSuffix
The provided suffix is too long.
NotUsernameAuthority
The sender does not have permission to issue a username.
NoAllocation
The authority cannot allocate any more usernames.
InvalidSignature
The signature on a username was not valid.
RequiresSignature
Setting this username requires a signature, but none was provided.
InvalidUsername
The username does not meet the requirements.
UsernameTaken
The username is already taken.
NoUsername
The requested username does not exist.
NotExpired
The username cannot be forcefully removed because it can still be accepted.