pub type Event = Event;
The Event enum of this pallet
Event
pub enum Event { NewSession { session_index: u32, }, }
New session has happened. Note that the argument is the session index, not the block number as the type might suggest.
session_index: u32