pub type Error = Error;Expand description
Error for the vesting pallet.
Aliased Type
pub enum Error {
NotVesting,
AtMaxVestingSchedules,
AmountLow,
ScheduleIndexOutOfBounds,
InvalidScheduleParams,
}Variants
NotVesting
The account given is not vesting.
AtMaxVestingSchedules
The account already has MaxVestingSchedules count of schedules and thus
cannot add another one. Consider merging existing schedules in order to add another.
AmountLow
Amount being transferred is too low to create a vesting schedule.
ScheduleIndexOutOfBounds
An index was out of bounds of the vesting schedules.
InvalidScheduleParams
Failed to create a new schedule because some parameter was invalid.